"""
    pygments.lexers.math
    ~~~~~~~~~~~~~~~~~~~~

    Just export lexers that were contained in this module.

    :copyright: Copyright 2006-present by the Pygments team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

# ruff: noqa: F401
from pygments.lexers.python import NumPyLexer
from pygments.lexers.matlab import MatlabLexer, MatlabSessionLexer, \
    OctaveLexer, ScilabLexer
from pygments.lexers.julia import JuliaLexer, JuliaConsoleLexer
from pygments.lexers.r import RConsoleLexer, SLexer, RdLexer
from pygments.lexers.modeling import BugsLexer, JagsLexer, StanLexer
from pygments.lexers.idl import IDLLexer
from pygments.lexers.algebra import MuPADLexer

__all__ = []



"""
    pygments.lexers._lasso_builtins
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    Built-in Lasso types, traits, methods, and members.

    :copyright: Copyright 2006-present by the Pygments team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

BUILTINS = {
    'Types': (
        'array',
        'atbegin',
        'boolean',
        'bson_iter',
        'bson',
        'bytes_document_body',
        'bytes',
        'cache_server_element',
        'cache_server',
        'capture',
        'client_address',
        'client_ip',
        'component_container',
        'component_render_state',
        'component',
        'curl',
        'curltoken',
        'currency',
        'custom',
        'data_document',
        'database_registry',
        'date',
        'dateandtime',
        'dbgp_packet',
        'dbgp_server',
        'debugging_stack',
        'decimal',
        'delve',
        'dir',
        'dirdesc',
        'dns_response',
        'document_base',
        'document_body',
        'document_header',
        'dsinfo',
        'duration',
        'eacher',
        'email_compose',
        'email_parse',
        'email_pop',
        'email_queue_impl_base',
        'email_queue_impl',
        'email_smtp',
        'email_stage_impl_base',
        'email_stage_impl',
        'fastcgi_each_fcgi_param',
        'fastcgi_server',
        'fcgi_record',
        'fcgi_request',
        'file',
        'filedesc',
        'filemaker_datasource',
        'generateforeachkeyed',
        'generateforeachunkeyed',
        'generateseries',
        'hash_map',
        'html_atomic_element',
        'html_attr',
        'html_base',
        'html_binary',
        'html_br',
        'html_cdata',
        'html_container_element',
        'html_div',
        'html_document_body',
        'html_document_head',
        'html_eol',
        'html_fieldset',
        'html_form',
        'html_h1',
        'html_h2',
        'html_h3',
        'html_h4',
        'html_h5',
        'html_h6',
        'html_hr',
        'html_img',
        'html_input',
        'html_json',
        'html_label',
        'html_legend',
        'html_link',
        'html_meta',
        'html_object',
        'html_option',
        'html_raw',
        'html_script',
        'html_select',
        'html_span',
        'html_style',
        'html_table',
        'html_td',
        'html_text',
        'html_th',
        'html_tr',
        'http_document_header',
        'http_document',
        'http_error',
        'http_header_field',
        'http_server_connection_handler_globals',
        'http_server_connection_handler',
        'http_server_request_logger_thread',
        'http_server_web_connection',
        'http_server',
        'image',
        'include_cache',
        'inline_type',
        'integer',
        'java_jnienv',
        'jbyte',
        'jbytearray',
        'jchar',
        'jchararray',
        'jfieldid',
        'jfloat',
        'jint',
        'jmethodid',
        'jobject',
        'jshort',
        'json_decode',
        'json_encode',
        'json_literal',
        'json_object',
        'keyword',
        'lassoapp_compiledsrc_appsource',
        'lassoapp_compiledsrc_fileresource',
        'lassoapp_content_rep_halt',
        'lassoapp_dirsrc_appsource',
        'lassoapp_dirsrc_fileresource',
        'lassoapp_installer',
        'lassoapp_livesrc_appsource',
        'lassoapp_livesrc_fileresource',
        'lassoapp_long_expiring_bytes',
        'lassoapp_manualsrc_appsource',
        'lassoapp_zip_file_server',
        'lassoapp_zipsrc_appsource',
        'lassoapp_zipsrc_fileresource',
        'ldap',
        'library_thread_loader',
        'list_node',
        'list',
        'locale',
        'log_impl_base',
        'log_impl',
        'magick_image',
        'map_node',
        'map',
        'memberstream',
        'memory_session_driver_impl_entry',
        'memory_session_driver_impl',
        'memory_session_driver',
        'mime_reader',
        'mongo_client',
        'mongo_collection',
        'mongo_cursor',
        'mustache_ctx',
        'mysql_session_driver_impl',
        'mysql_session_driver',
        'net_named_pipe',
        'net_tcp_ssl',
        'net_tcp',
        'net_udp_packet',
        'net_udp',
        'null',
        'odbc_session_driver_impl',
        'odbc_session_driver',
        'opaque',
        'os_process',
        'pair_compare',
        'pair',
        'pairup',
        'pdf_barcode',
        'pdf_chunk',
        'pdf_color',
        'pdf_doc',
        'pdf_font',
        'pdf_hyphenator',
        'pdf_image',
        'pdf_list',
        'pdf_paragraph',
        'pdf_phrase',
        'pdf_read',
        'pdf_table',
        'pdf_text',
        'pdf_typebase',
        'percent',
        'portal_impl',
        'queriable_groupby',
        'queriable_grouping',
        'queriable_groupjoin',
        'queriable_join',
        'queriable_orderby',
        'queriable_orderbydescending',
        'queriable_select',
        'queriable_selectmany',
        'queriable_skip',
        'queriable_take',
        'queriable_thenby',
        'queriable_thenbydescending',
        'queriable_where',
        'queue',
        'raw_document_body',
        'regexp',
        'repeat',
        'scientific',
        'security_registry',
        'serialization_element',
        'serialization_object_identity_compare',
        'serialization_reader',
        'serialization_writer_ref',
        'serialization_writer_standin',
        'serialization_writer',
        'session_delete_expired_thread',
        'set',
        'signature',
        'sourcefile',
        'sqlite_column',
        'sqlite_currentrow',
        'sqlite_db',
        'sqlite_results',
        'sqlite_session_driver_impl_entry',
        'sqlite_session_driver_impl',
        'sqlite_session_driver',
        'sqlite_table',
        'sqlite3_stmt',
        'sqlite3',
        'staticarray',
        'string',
        'sys_process',
        'tag',
        'text_document',
        'tie',
        'timeonly',
        'trait',
        'tree_base',
        'tree_node',
        'tree_nullnode',
        'ucal',
        'usgcpu',
        'usgvm',
        'void',
        'web_error_atend',
        'web_node_base',
        'web_node_content_representation_css_specialized',
        'web_node_content_representation_html_specialized',
        'web_node_content_representation_js_specialized',
        'web_node_content_representation_xhr_container',
        'web_node_echo',
        'web_node_root',
        'web_request_impl',
        'web_request',
        'web_response_impl',
        'web_response',
        'web_router',
        'websocket_handler',
        'worker_pool',
        'xml_attr',
        'xml_cdatasection',
        'xml_characterdata',
        'xml_comment',
        'xml_document',
        'xml_documentfragment',
        'xml_documenttype',
        'xml_domimplementation',
        'xml_element',
        'xml_entity',
        'xml_entityreference',
        'xml_namednodemap_attr',
        'xml_namednodemap_ht',
        'xml_namednodemap',
        'xml_node',
        'xml_nodelist',
        'xml_notation',
        'xml_processinginstruction',
        'xml_text',
        'xmlstream',
        'zip_file_impl',
        'zip_file',
        'zip_impl',
        'zip',
    ),
    'Traits': (
        'any',
        'formattingbase',
        'html_attributed',
        'html_element_coreattrs',
        'html_element_eventsattrs',
        'html_element_i18nattrs',
        'lassoapp_capabilities',
        'lassoapp_resource',
        'lassoapp_source',
        'queriable_asstring',
        'session_driver',
        'trait_array',
        'trait_asstring',
        'trait_backcontractible',
        'trait_backended',
        'trait_backexpandable',
        'trait_close',
        'trait_contractible',
        'trait_decompose_assignment',
        'trait_doubleended',
        'trait_each_sub',
        'trait_encodeurl',
        'trait_endedfullymutable',
        'trait_expandable',
        'trait_file',
        'trait_finite',
        'trait_finiteforeach',
        'trait_foreach',
        'trait_foreachtextelement',
        'trait_frontcontractible',
        'trait_frontended',
        'trait_frontexpandable',
        'trait_fullymutable',
        'trait_generator',
        'trait_generatorcentric',
        'trait_hashable',
        'trait_json_serialize',
        'trait_keyed',
        'trait_keyedfinite',
        'trait_keyedforeach',
        'trait_keyedmutable',
        'trait_list',
        'trait_map',
        'trait_net',
        'trait_pathcomponents',
        'trait_positionallykeyed',
        'trait_positionallysearchable',
        'trait_queriable',
        'trait_queriablelambda',
        'trait_readbytes',
        'trait_readstring',
        'trait_scalar',
        'trait_searchable',
        'trait_serializable',
        'trait_setencoding',
        'trait_setoperations',
        'trait_stack',
        'trait_treenode',
        'trait_writebytes',
        'trait_writestring',
        'trait_xml_elementcompat',
        'trait_xml_nodecompat',
        'web_connection',
        'web_node_container',
        'web_node_content_css_specialized',
        'web_node_content_document',
        'web_node_content_html_specialized',
        'web_node_content_js_specialized',
        'web_node_content_json_specialized',
        'web_node_content_representation',
        'web_node_content',
        'web_node_postable',
        'web_node',
    ),
    'Unbound Methods': (
        'abort_clear',
        'abort_now',
        'abort',
        'action_param',
        'action_params',
        'action_statement',
        'admin_authorization',
        'admin_currentgroups',
        'admin_currentuserid',
        'admin_currentusername',
        'admin_getpref',
        'admin_initialize',
        'admin_lassoservicepath',
        'admin_removepref',
        'admin_setpref',
        'admin_userexists',
        'all',
        'auth_admin',
        'auth_check',
        'auth_custom',
        'auth_group',
        'auth_prompt',
        'auth_user',
        'bom_utf16be',
        'bom_utf16le',
        'bom_utf32be',
        'bom_utf32le',
        'bom_utf8',
        'bw',
        'capture_nearestloopabort',
        'capture_nearestloopcontinue',
        'capture_nearestloopcount',
        'checked',
        'cipher_decrypt_private',
        'cipher_decrypt_public',
        'cipher_decrypt',
        'cipher_digest',
        'cipher_encrypt_private',
        'cipher_encrypt_public',
        'cipher_encrypt',
        'cipher_generate_key',
        'cipher_hmac',
        'cipher_keylength',
        'cipher_list',
        'cipher_open',
        'cipher_seal',
        'cipher_sign',
        'cipher_verify',
        'client_addr',
        'client_authorization',
        'client_browser',
        'client_contentlength',
        'client_contenttype',
        'client_cookielist',
        'client_cookies',
        'client_encoding',
        'client_formmethod',
        'client_getargs',
        'client_getparam',
        'client_getparams',
        'client_headers',
        'client_integertoip',
        'client_iptointeger',
        'client_password',
        'client_postargs',
        'client_postparam',
        'client_postparams',
        'client_type',
        'client_url',
        'client_username',
        'cn',
        'column_name',
        'column_names',
        'column_type',
        'column',
        'compress',
        'content_addheader',
        'content_body',
        'content_encoding',
        'content_header',
        'content_replaceheader',
        'content_type',
        'cookie_set',
        'cookie',
        'curl_easy_cleanup',
        'curl_easy_duphandle',
        'curl_easy_getinfo',
        'curl_easy_init',
        'curl_easy_reset',
        'curl_easy_setopt',
        'curl_easy_strerror',
        'curl_getdate',
        'curl_http_version_1_0',
        'curl_http_version_1_1',
        'curl_http_version_none',
        'curl_ipresolve_v4',
        'curl_ipresolve_v6',
        'curl_ipresolve_whatever',
        'curl_multi_perform',
        'curl_multi_result',
        'curl_netrc_ignored',
        'curl_netrc_optional',
        'curl_netrc_required',
        'curl_sslversion_default',
        'curl_sslversion_sslv2',
        'curl_sslversion_sslv3',
        'curl_sslversion_tlsv1',
        'curl_version_asynchdns',
        'curl_version_debug',
        'curl_version_gssnegotiate',
        'curl_version_idn',
        'curl_version_info',
        'curl_version_ipv6',
        'curl_version_kerberos4',
        'curl_version_largefile',
        'curl_version_libz',
        'curl_version_ntlm',
        'curl_version_spnego',
        'curl_version_ssl',
        'curl_version',
        'curlauth_any',
        'curlauth_anysafe',
        'curlauth_basic',
        'curlauth_digest',
        'curlauth_gssnegotiate',
        'curlauth_none',
        'curlauth_ntlm',
        'curle_aborted_by_callback',
        'curle_bad_calling_order',
        'curle_bad_content_encoding',
        'curle_bad_download_resume',
        'curle_bad_function_argument',
        'curle_bad_password_entered',
        'curle_couldnt_connect',
        'curle_couldnt_resolve_host',
        'curle_couldnt_resolve_proxy',
        'curle_failed_init',
        'curle_file_couldnt_read_file',
        'curle_filesize_exceeded',
        'curle_ftp_access_denied',
        'curle_ftp_cant_get_host',
        'curle_ftp_cant_reconnect',
        'curle_ftp_couldnt_get_size',
        'curle_ftp_couldnt_retr_file',
        'curle_ftp_couldnt_set_ascii',
        'curle_ftp_couldnt_set_binary',
        'curle_ftp_couldnt_use_rest',
        'curle_ftp_port_failed',
        'curle_ftp_quote_error',
        'curle_ftp_ssl_failed',
        'curle_ftp_user_password_incorrect',
        'curle_ftp_weird_227_format',
        'curle_ftp_weird_pass_reply',
        'curle_ftp_weird_pasv_reply',
        'curle_ftp_weird_server_reply',
        'curle_ftp_weird_user_reply',
        'curle_ftp_write_error',
        'curle_function_not_found',
        'curle_got_nothing',
        'curle_http_post_error',
        'curle_http_range_error',
        'curle_http_returned_error',
        'curle_interface_failed',
        'curle_ldap_cannot_bind',
        'curle_ldap_invalid_url',
        'curle_ldap_search_failed',
        'curle_library_not_found',
        'curle_login_denied',
        'curle_malformat_user',
        'curle_obsolete',
        'curle_ok',
        'curle_operation_timeouted',
        'curle_out_of_memory',
        'curle_partial_file',
        'curle_read_error',
        'curle_recv_error',
        'curle_send_error',
        'curle_send_fail_rewind',
        'curle_share_in_use',
        'curle_ssl_cacert',
        'curle_ssl_certproblem',
        'curle_ssl_cipher',
        'curle_ssl_connect_error',
        'curle_ssl_engine_initfailed',
        'curle_ssl_engine_notfound',
        'curle_ssl_engine_setfailed',
        'curle_ssl_peer_certificate',
        'curle_telnet_option_syntax',
        'curle_too_many_redirects',
        'curle_unknown_telnet_option',
        'curle_unsupported_protocol',
        'curle_url_malformat_user',
        'curle_url_malformat',
        'curle_write_error',
        'curlftpauth_default',
        'curlftpauth_ssl',
        'curlftpauth_tls',
        'curlftpssl_all',
        'curlftpssl_control',
        'curlftpssl_last',
        'curlftpssl_none',
        'curlftpssl_try',
        'curlinfo_connect_time',
        'curlinfo_content_length_download',
        'curlinfo_content_length_upload',
        'curlinfo_content_type',
        'curlinfo_effective_url',
        'curlinfo_filetime',
        'curlinfo_header_size',
        'curlinfo_http_connectcode',
        'curlinfo_httpauth_avail',
        'curlinfo_namelookup_time',
        'curlinfo_num_connects',
        'curlinfo_os_errno',
        'curlinfo_pretransfer_time',
        'curlinfo_proxyauth_avail',
        'curlinfo_redirect_count',
        'curlinfo_redirect_time',
        'curlinfo_request_size',
        'curlinfo_response_code',
        'curlinfo_size_download',
        'curlinfo_size_upload',
        'curlinfo_speed_download',
        'curlinfo_speed_upload',
        'curlinfo_ssl_engines',
        'curlinfo_ssl_verifyresult',
        'curlinfo_starttransfer_time',
        'curlinfo_total_time',
        'curlmsg_done',
        'curlopt_autoreferer',
        'curlopt_buffersize',
        'curlopt_cainfo',
        'curlopt_capath',
        'curlopt_connecttimeout',
        'curlopt_cookie',
        'curlopt_cookiefile',
        'curlopt_cookiejar',
        'curlopt_cookiesession',
        'curlopt_crlf',
        'curlopt_customrequest',
        'curlopt_dns_use_global_cache',
        'curlopt_egdsocket',
        'curlopt_encoding',
        'curlopt_failonerror',
        'curlopt_filetime',
        'curlopt_followlocation',
        'curlopt_forbid_reuse',
        'curlopt_fresh_connect',
        'curlopt_ftp_account',
        'curlopt_ftp_create_missing_dirs',
        'curlopt_ftp_response_timeout',
        'curlopt_ftp_ssl',
        'curlopt_ftp_use_eprt',
        'curlopt_ftp_use_epsv',
        'curlopt_ftpappend',
        'curlopt_ftplistonly',
        'curlopt_ftpport',
        'curlopt_ftpsslauth',
        'curlopt_header',
        'curlopt_http_version',
        'curlopt_http200aliases',
        'curlopt_httpauth',
        'curlopt_httpget',
        'curlopt_httpheader',
        'curlopt_httppost',
        'curlopt_httpproxytunnel',
        'curlopt_infilesize_large',
        'curlopt_infilesize',
        'curlopt_interface',
        'curlopt_ipresolve',
        'curlopt_krb4level',
        'curlopt_low_speed_limit',
        'curlopt_low_speed_time',
        'curlopt_mail_from',
        'curlopt_mail_rcpt',
        'curlopt_maxconnects',
        'curlopt_maxfilesize_large',
        'curlopt_maxfilesize',
        'curlopt_maxredirs',
        'curlopt_netrc_file',
        'curlopt_netrc',
        'curlopt_nobody',
        'curlopt_noprogress',
        'curlopt_port',
        'curlopt_post',
        'curlopt_postfields',
        'curlopt_postfieldsize_large',
        'curlopt_postfieldsize',
        'curlopt_postquote',
        'curlopt_prequote',
        'curlopt_proxy',
        'curlopt_proxyauth',
        'curlopt_proxyport',
        'curlopt_proxytype',
        'curlopt_proxyuserpwd',
        'curlopt_put',
        'curlopt_quote',
        'curlopt_random_file',
        'curlopt_range',
        'curlopt_readdata',
        'curlopt_referer',
        'curlopt_resume_from_large',
        'curlopt_resume_from',
        'curlopt_ssl_cipher_list',
        'curlopt_ssl_verifyhost',
        'curlopt_ssl_verifypeer',
        'curlopt_sslcert',
        'curlopt_sslcerttype',
        'curlopt_sslengine_default',
        'curlopt_sslengine',
        'curlopt_sslkey',
        'curlopt_sslkeypasswd',
        'curlopt_sslkeytype',
        'curlopt_sslversion',
        'curlopt_tcp_nodelay',
        'curlopt_timecondition',
        'curlopt_timeout',
        'curlopt_timevalue',
        'curlopt_transfertext',
        'curlopt_unrestricted_auth',
        'curlopt_upload',
        'curlopt_url',
        'curlopt_use_ssl',
        'curlopt_useragent',
        'curlopt_userpwd',
        'curlopt_verbose',
        'curlopt_writedata',
        'curlproxy_http',
        'curlproxy_socks4',
        'curlproxy_socks5',
        'database_adddefaultsqlitehost',
        'database_database',
        'database_initialize',
        'database_name',
        'database_qs',
        'database_table_database_tables',
        'database_table_datasource_databases',
        'database_table_datasource_hosts',
        'database_table_datasources',
        'database_table_table_fields',
        'database_util_cleanpath',
        'dbgp_stop_stack_name',
        'debugging_break',
        'debugging_breakpoint_get',
        'debugging_breakpoint_list',
        'debugging_breakpoint_remove',
        'debugging_breakpoint_set',
        'debugging_breakpoint_update',
        'debugging_context_locals',
        'debugging_context_self',
        'debugging_context_vars',
        'debugging_detach',
        'debugging_enabled',
        'debugging_get_context',
        'debugging_get_stack',
        'debugging_run',
        'debugging_step_in',
        'debugging_step_out',
        'debugging_step_over',
        'debugging_stop',
        'debugging_terminate',
        'decimal_random',
        'decompress',
        'decrypt_blowfish',
        'define_atbegin',
        'define_atend',
        'dns_default',
        'dns_lookup',
        'document',
        'email_attachment_mime_type',
        'email_batch',
        'email_digestchallenge',
        'email_digestresponse',
        'email_extract',
        'email_findemails',
        'email_fix_address_list',
        'email_fix_address',
        'email_fs_error_clean',
        'email_immediate',
        'email_initialize',
        'email_merge',
        'email_mxlookup',
        'email_pop_priv_extract',
        'email_pop_priv_quote',
        'email_pop_priv_substring',
        'email_queue',
        'email_result',
        'email_safeemail',
        'email_send',
        'email_status',
        'email_token',
        'email_translatebreakstocrlf',
        'encode_qheader',
        'encoding_iso88591',
        'encoding_utf8',
        'encrypt_blowfish',
        'encrypt_crammd5',
        'encrypt_hmac',
        'encrypt_md5',
        'eol',
        'eq',
        'error_code_aborted',
        'error_code_dividebyzero',
        'error_code_filenotfound',
        'error_code_invalidparameter',
        'error_code_methodnotfound',
        'error_code_networkerror',
        'error_code_noerror',
        'error_code_resnotfound',
        'error_code_runtimeassertion',
        'error_code',
        'error_msg_aborted',
        'error_msg_dividebyzero',
        'error_msg_filenotfound',
        'error_msg_invalidparameter',
        'error_msg_methodnotfound',
        'error_msg_networkerror',
        'error_msg_noerror',
        'error_msg_resnotfound',
        'error_msg_runtimeassertion',
        'error_msg',
        'error_obj',
        'error_pop',
        'error_push',
        'error_reset',
        'error_stack',
        'escape_tag',
        'evdns_resolve_ipv4',
        'evdns_resolve_ipv6',
        'evdns_resolve_reverse_ipv6',
        'evdns_resolve_reverse',
        'ew',
        'fail_if',
        'fail_ifnot',
        'fail_now',
        'fail',
        'failure_clear',
        'fastcgi_createfcgirequest',
        'fastcgi_handlecon',
        'fastcgi_handlereq',
        'fastcgi_initialize',
        'fastcgi_initiate_request',
        'fcgi_abort_request',
        'fcgi_authorize',
        'fcgi_begin_request',
        'fcgi_bodychunksize',
        'fcgi_cant_mpx_conn',
        'fcgi_data',
        'fcgi_end_request',
        'fcgi_filter',
        'fcgi_get_values_result',
        'fcgi_get_values',
        'fcgi_keep_conn',
        'fcgi_makeendrequestbody',
        'fcgi_makestdoutbody',
        'fcgi_max_conns',
        'fcgi_max_reqs',
        'fcgi_mpxs_conns',
        'fcgi_null_request_id',
        'fcgi_overloaded',
        'fcgi_params',
        'fcgi_read_timeout_seconds',
        'fcgi_readparam',
        'fcgi_request_complete',
        'fcgi_responder',
        'fcgi_stderr',
        'fcgi_stdin',
        'fcgi_stdout',
        'fcgi_unknown_role',
        'fcgi_unknown_type',
        'fcgi_version_1',
        'fcgi_x_stdin',
        'field_name',
        'field_names',
        'field',
        'file_copybuffersize',
        'file_defaultencoding',
        'file_forceroot',
        'file_modechar',
        'file_modeline',
        'file_stderr',
        'file_stdin',
        'file_stdout',
        'file_tempfile',
        'filemakerds_initialize',
        'filemakerds',
        'found_count',
        'ft',
        'ftp_deletefile',
        'ftp_getdata',
        'ftp_getfile',
        'ftp_getlisting',
        'ftp_putdata',
        'ftp_putfile',
        'full',
        'generateforeach',
        'gt',
        'gte',
        'handle_failure',
        'handle',
        'hash_primes',
        'html_comment',
        'http_char_colon',
        'http_char_cr',
        'http_char_htab',
        'http_char_lf',
        'http_char_question',
        'http_char_space',
        'http_default_files',
        'http_read_headers',
        'http_read_timeout_secs',
        'http_server_apps_path',
        'http_server_request_logger',
        'if_empty',
        'if_false',
        'if_null',
        'if_true',
        'include_cache_compare',
        'include_currentpath',
        'include_filepath',
        'include_localpath',
        'include_once',
        'include_path',
        'include_raw',
        'include_url',
        'include',
        'includes',
        'inline_colinfo_name_pos',
        'inline_colinfo_type_pos',
        'inline_colinfo_valuelist_pos',
        'inline_columninfo_pos',
        'inline_foundcount_pos',
        'inline_namedget',
        'inline_namedput',
        'inline_resultrows_pos',
        'inline_scopeget',
        'inline_scopepop',
        'inline_scopepush',
        'inline',
        'integer_bitor',
        'integer_random',
        'io_dir_dt_blk',
        'io_dir_dt_chr',
        'io_dir_dt_dir',
        'io_dir_dt_fifo',
        'io_dir_dt_lnk',
        'io_dir_dt_reg',
        'io_dir_dt_sock',
        'io_dir_dt_unknown',
        'io_dir_dt_wht',
        'io_file_access',
        'io_file_chdir',
        'io_file_chmod',
        'io_file_chown',
        'io_file_dirname',
        'io_file_f_dupfd',
        'io_file_f_getfd',
        'io_file_f_getfl',
        'io_file_f_getlk',
        'io_file_f_rdlck',
        'io_file_f_setfd',
        'io_file_f_setfl',
        'io_file_f_setlk',
        'io_file_f_setlkw',
        'io_file_f_test',
        'io_file_f_tlock',
        'io_file_f_ulock',
        'io_file_f_unlck',
        'io_file_f_wrlck',
        'io_file_fd_cloexec',
        'io_file_fioasync',
        'io_file_fioclex',
        'io_file_fiodtype',
        'io_file_fiogetown',
        'io_file_fionbio',
        'io_file_fionclex',
        'io_file_fionread',
        'io_file_fiosetown',
        'io_file_getcwd',
        'io_file_lchown',
        'io_file_link',
        'io_file_lockf',
        'io_file_lstat_atime',
        'io_file_lstat_mode',
        'io_file_lstat_mtime',
        'io_file_lstat_size',
        'io_file_mkdir',
        'io_file_mkfifo',
        'io_file_mkstemp',
        'io_file_o_append',
        'io_file_o_async',
        'io_file_o_creat',
        'io_file_o_excl',
        'io_file_o_exlock',
        'io_file_o_fsync',
        'io_file_o_nofollow',
        'io_file_o_nonblock',
        'io_file_o_rdonly',
        'io_file_o_rdwr',
        'io_file_o_shlock',
        'io_file_o_sync',
        'io_file_o_trunc',
        'io_file_o_wronly',
        'io_file_pipe',
        'io_file_readlink',
        'io_file_realpath',
        'io_file_remove',
        'io_file_rename',
        'io_file_rmdir',
        'io_file_s_ifblk',
        'io_file_s_ifchr',
        'io_file_s_ifdir',
        'io_file_s_ififo',
        'io_file_s_iflnk',
        'io_file_s_ifmt',
        'io_file_s_ifreg',
        'io_file_s_ifsock',
        'io_file_s_irgrp',
        'io_file_s_iroth',
        'io_file_s_irusr',
        'io_file_s_irwxg',
        'io_file_s_irwxo',
        'io_file_s_irwxu',
        'io_file_s_isgid',
        'io_file_s_isuid',
        'io_file_s_isvtx',
        'io_file_s_iwgrp',
        'io_file_s_iwoth',
        'io_file_s_iwusr',
        'io_file_s_ixgrp',
        'io_file_s_ixoth',
        'io_file_s_ixusr',
        'io_file_seek_cur',
        'io_file_seek_end',
        'io_file_seek_set',
        'io_file_stat_atime',
        'io_file_stat_mode',
        'io_file_stat_mtime',
        'io_file_stat_size',
        'io_file_stderr',
        'io_file_stdin',
        'io_file_stdout',
        'io_file_symlink',
        'io_file_tempnam',
        'io_file_truncate',
        'io_file_umask',
        'io_file_unlink',
        'io_net_accept',
        'io_net_af_inet',
        'io_net_af_inet6',
        'io_net_af_unix',
        'io_net_bind',
        'io_net_connect',
        'io_net_getpeername',
        'io_net_getsockname',
        'io_net_ipproto_ip',
        'io_net_ipproto_udp',
        'io_net_listen',
        'io_net_msg_oob',
        'io_net_msg_peek',
        'io_net_msg_waitall',
        'io_net_recv',
        'io_net_recvfrom',
        'io_net_send',
        'io_net_sendto',
        'io_net_shut_rd',
        'io_net_shut_rdwr',
        'io_net_shut_wr',
        'io_net_shutdown',
        'io_net_so_acceptconn',
        'io_net_so_broadcast',
        'io_net_so_debug',
        'io_net_so_dontroute',
        'io_net_so_error',
        'io_net_so_keepalive',
        'io_net_so_linger',
        'io_net_so_oobinline',
        'io_net_so_rcvbuf',
        'io_net_so_rcvlowat',
        'io_net_so_rcvtimeo',
        'io_net_so_reuseaddr',
        'io_net_so_sndbuf',
        'io_net_so_sndlowat',
        'io_net_so_sndtimeo',
        'io_net_so_timestamp',
        'io_net_so_type',
        'io_net_so_useloopback',
        'io_net_sock_dgram',
        'io_net_sock_raw',
        'io_net_sock_rdm',
        'io_net_sock_seqpacket',
        'io_net_sock_stream',
        'io_net_socket',
        'io_net_sol_socket',
        'io_net_ssl_accept',
        'io_net_ssl_begin',
        'io_net_ssl_connect',
        'io_net_ssl_end',
        'io_net_ssl_error',
        'io_net_ssl_errorstring',
        'io_net_ssl_funcerrorstring',
        'io_net_ssl_liberrorstring',
        'io_net_ssl_read',
        'io_net_ssl_reasonerrorstring',
        'io_net_ssl_setacceptstate',
        'io_net_ssl_setconnectstate',
        'io_net_ssl_setverifylocations',
        'io_net_ssl_shutdown',
        'io_net_ssl_usecertificatechainfile',
        'io_net_ssl_useprivatekeyfile',
        'io_net_ssl_write',
        'java_jvm_create',
        'java_jvm_getenv',
        'jdbc_initialize',
        'json_back_slash',
        'json_back_space',
        'json_close_array',
        'json_close_object',
        'json_colon',
        'json_comma',
        'json_consume_array',
        'json_consume_object',
        'json_consume_string',
        'json_consume_token',
        'json_cr',
        'json_debug',
        'json_deserialize',
        'json_e_lower',
        'json_e_upper',
        'json_f_lower',
        'json_form_feed',
        'json_forward_slash',
        'json_lf',
        'json_n_lower',
        'json_negative',
        'json_open_array',
        'json_open_object',
        'json_period',
        'json_positive',
        'json_quote_double',
        'json_rpccall',
        'json_serialize',
        'json_t_lower',
        'json_tab',
        'json_white_space',
        'keycolumn_name',
        'keycolumn_value',
        'keyfield_name',
        'keyfield_value',
        'lasso_currentaction',
        'lasso_errorreporting',
        'lasso_executiontimelimit',
        'lasso_methodexists',
        'lasso_tagexists',
        'lasso_uniqueid',
        'lasso_version',
        'lassoapp_current_app',
        'lassoapp_current_include',
        'lassoapp_do_with_include',
        'lassoapp_exists',
        'lassoapp_find_missing_file',
        'lassoapp_format_mod_date',
        'lassoapp_get_capabilities_name',
        'lassoapp_include_current',
        'lassoapp_include',
        'lassoapp_initialize_db',
        'lassoapp_initialize',
        'lassoapp_invoke_resource',
        'lassoapp_issourcefileextension',
        'lassoapp_link',
        'lassoapp_load_module',
        'lassoapp_mime_get',
        'lassoapp_mime_type_appcache',
        'lassoapp_mime_type_css',
        'lassoapp_mime_type_csv',
        'lassoapp_mime_type_doc',
        'lassoapp_mime_type_docx',
        'lassoapp_mime_type_eof',
        'lassoapp_mime_type_eot',
        'lassoapp_mime_type_gif',
        'lassoapp_mime_type_html',
        'lassoapp_mime_type_ico',
        'lassoapp_mime_type_jpg',
        'lassoapp_mime_type_js',
        'lassoapp_mime_type_lasso',
        'lassoapp_mime_type_map',
        'lassoapp_mime_type_pdf',
        'lassoapp_mime_type_png',
        'lassoapp_mime_type_ppt',
        'lassoapp_mime_type_rss',
        'lassoapp_mime_type_svg',
        'lassoapp_mime_type_swf',
        'lassoapp_mime_type_tif',
        'lassoapp_mime_type_ttf',
        'lassoapp_mime_type_txt',
        'lassoapp_mime_type_woff',
        'lassoapp_mime_type_xaml',
        'lassoapp_mime_type_xap',
        'lassoapp_mime_type_xbap',
        'lassoapp_mime_type_xhr',
        'lassoapp_mime_type_xml',
        'lassoapp_mime_type_zip',
        'lassoapp_path_to_method_name',
        'lassoapp_settingsdb',
        'layout_name',
        'lcapi_datasourceadd',
        'lcapi_datasourcecloseconnection',
        'lcapi_datasourcedelete',
        'lcapi_datasourceduplicate',
        'lcapi_datasourceexecsql',
        'lcapi_datasourcefindall',
        'lcapi_datasourceimage',
        'lcapi_datasourceinfo',
        'lcapi_datasourceinit',
        'lcapi_datasourcematchesname',
        'lcapi_datasourcenames',
        'lcapi_datasourcenothing',
        'lcapi_datasourceopand',
        'lcapi_datasourceopany',
        'lcapi_datasourceopbw',
        'lcapi_datasourceopct',
        'lcapi_datasourceopeq',
        'lcapi_datasourceopew',
        'lcapi_datasourceopft',
        'lcapi_datasourceopgt',
        'lcapi_datasourceopgteq',
        'lcapi_datasourceopin',
        'lcapi_datasourceoplt',
        'lcapi_datasourceoplteq',
        'lcapi_datasourceopnbw',
        'lcapi_datasourceopnct',
        'lcapi_datasourceopneq',
        'lcapi_datasourceopnew',
        'lcapi_datasourceopnin',
        'lcapi_datasourceopno',
        'lcapi_datasourceopnot',
        'lcapi_datasourceopnrx',
        'lcapi_datasourceopor',
        'lcapi_datasourceoprx',
        'lcapi_datasourcepreparesql',
        'lcapi_datasourceprotectionnone',
        'lcapi_datasourceprotectionreadonly',
        'lcapi_datasourcerandom',
        'lcapi_datasourceschemanames',
        'lcapi_datasourcescripts',
        'lcapi_datasourcesearch',
        'lcapi_datasourcesortascending',
        'lcapi_datasourcesortcustom',
        'lcapi_datasourcesortdescending',
        'lcapi_datasourcetablenames',
        'lcapi_datasourceterm',
        'lcapi_datasourcetickle',
        'lcapi_datasourcetypeblob',
        'lcapi_datasourcetypeboolean',
        'lcapi_datasourcetypedate',
        'lcapi_datasourcetypedecimal',
        'lcapi_datasourcetypeinteger',
        'lcapi_datasourcetypestring',
        'lcapi_datasourceunpreparesql',
        'lcapi_datasourceupdate',
        'lcapi_fourchartointeger',
        'lcapi_listdatasources',
        'lcapi_loadmodule',
        'lcapi_loadmodules',
        'lcapi_updatedatasourceslist',
        'ldap_scope_base',
        'ldap_scope_children',
        'ldap_scope_onelevel',
        'ldap_scope_subtree',
        'library_once',
        'library',
        'ljapi_initialize',
        'locale_availablelocales',
        'locale_canada',
        'locale_canadafrench',
        'locale_china',
        'locale_chinese',
        'locale_default',
        'locale_english',
        'locale_format_style_date_time',
        'locale_format_style_default',
        'locale_format_style_full',
        'locale_format_style_long',
        'locale_format_style_medium',
        'locale_format_style_none',
        'locale_format_style_short',
        'locale_format',
        'locale_france',
        'locale_french',
        'locale_german',
        'locale_germany',
        'locale_isocountries',
        'locale_isolanguages',
        'locale_italian',
        'locale_italy',
        'locale_japan',
        'locale_japanese',
        'locale_korea',
        'locale_korean',
        'locale_prc',
        'locale_setdefault',
        'locale_simplifiedchinese',
        'locale_taiwan',
        'locale_traditionalchinese',
        'locale_uk',
        'locale_us',
        'log_always',
        'log_critical',
        'log_deprecated',
        'log_destination_console',
        'log_destination_database',
        'log_destination_file',
        'log_detail',
        'log_initialize',
        'log_level_critical',
        'log_level_deprecated',
        'log_level_detail',
        'log_level_sql',
        'log_level_warning',
        'log_max_file_size',
        'log_setdestination',
        'log_sql',
        'log_trim_file_size',
        'log_warning',
        'log',
        'loop_abort',
        'loop_continue',
        'loop_count',
        'loop_key_pop',
        'loop_key_push',
        'loop_key',
        'loop_pop',
        'loop_push',
        'loop_value_pop',
        'loop_value_push',
        'loop_value',
        'loop',
        'lt',
        'lte',
        'main_thread_only',
        'max',
        'maxrecords_value',
        'median',
        'method_name',
        'micros',
        'millis',
        'min',
        'minimal',
        'mongo_insert_continue_on_error',
        'mongo_insert_no_validate',
        'mongo_insert_none',
        'mongo_query_await_data',
        'mongo_query_exhaust',
        'mongo_query_no_cursor_timeout',
        'mongo_query_none',
        'mongo_query_oplog_replay',
        'mongo_query_partial',
        'mongo_query_slave_ok',
        'mongo_query_tailable_cursor',
        'mongo_remove_none',
        'mongo_remove_single_remove',
        'mongo_update_multi_update',
        'mongo_update_no_validate',
        'mongo_update_none',
        'mongo_update_upsert',
        'mustache_compile_file',
        'mustache_compile_string',
        'mustache_include',
        'mysqlds',
        'namespace_global',
        'namespace_import',
        'namespace_using',
        'nbw',
        'ncn',
        'neq',
        'net_connectinprogress',
        'net_connectok',
        'net_typessl',
        'net_typessltcp',
        'net_typessludp',
        'net_typetcp',
        'net_typeudp',
        'net_waitread',
        'net_waittimeout',
        'net_waitwrite',
        'new',
        'none',
        'nrx',
        'nslookup',
        'odbc_session_driver_mssql',
        'odbc',
        'output_none',
        'output',
        'pdf_package',
        'pdf_rectangle',
        'pdf_serve',
        'pi',
        'portal',
        'postgresql',
        'process',
        'protect_now',
        'protect',
        'queriable_average',
        'queriable_defaultcompare',
        'queriable_do',
        'queriable_internal_combinebindings',
        'queriable_max',
        'queriable_min',
        'queriable_qsort',
        'queriable_reversecompare',
        'queriable_sum',
        'random_seed',
        'range',
        'records_array',
        'records_map',
        'records',
        'redirect_url',
        'referer_url',
        'referrer_url',
        'register_thread',
        'register',
        'response_filepath',
        'response_localpath',
        'response_path',
        'response_realm',
        'response_root',
        'resultset_count',
        'resultset',
        'resultsets',
        'rows_array',
        'rows_impl',
        'rows',
        'rx',
        'schema_name',
        'security_database',
        'security_default_realm',
        'security_initialize',
        'security_table_groups',
        'security_table_ug_map',
        'security_table_users',
        'selected',
        'series',
        'server_admin',
        'server_ip',
        'server_name',
        'server_port',
        'server_protocol',
        'server_push',
        'server_signature',
        'server_software',
        'session_abort',
        'session_addvar',
        'session_decorate',
        'session_deleteexpired',
        'session_end',
        'session_getdefaultdriver',
        'session_id',
        'session_initialize',
        'session_removevar',
        'session_result',
        'session_setdefaultdriver',
        'session_start',
        'shown_count',
        'shown_first',
        'shown_last',
        'site_id',
        'site_name',
        'skiprecords_value',
        'sleep',
        'split_thread',
        'sqlite_abort',
        'sqlite_auth',
        'sqlite_blob',
        'sqlite_busy',
        'sqlite_cantopen',
        'sqlite_constraint',
        'sqlite_corrupt',
        'sqlite_createdb',
        'sqlite_done',
        'sqlite_empty',
        'sqlite_error',
        'sqlite_float',
        'sqlite_format',
        'sqlite_full',
        'sqlite_integer',
        'sqlite_internal',
        'sqlite_interrupt',
        'sqlite_ioerr',
        'sqlite_locked',
        'sqlite_mismatch',
        'sqlite_misuse',
        'sqlite_nolfs',
        'sqlite_nomem',
        'sqlite_notadb',
        'sqlite_notfound',
        'sqlite_null',
        'sqlite_ok',
        'sqlite_perm',
        'sqlite_protocol',
        'sqlite_range',
        'sqlite_readonly',
        'sqlite_row',
        'sqlite_schema',
        'sqlite_setsleepmillis',
        'sqlite_setsleeptries',
        'sqlite_text',
        'sqlite_toobig',
        'sqliteconnector',
        'staticarray_join',
        'stdout',
        'stdoutnl',
        'string_validcharset',
        'suspend',
        'sys_appspath',
        'sys_chroot',
        'sys_clock',
        'sys_clockspersec',
        'sys_credits',
        'sys_databasespath',
        'sys_detach_exec',
        'sys_difftime',
        'sys_dll_ext',
        'sys_drand48',
        'sys_environ',
        'sys_eol',
        'sys_erand48',
        'sys_errno',
        'sys_exec_pid_to_os_pid',
        'sys_exec',
        'sys_exit',
        'sys_fork',
        'sys_garbagecollect',
        'sys_getbytessincegc',
        'sys_getchar',
        'sys_getegid',
        'sys_getenv',
        'sys_geteuid',
        'sys_getgid',
        'sys_getgrnam',
        'sys_getheapfreebytes',
        'sys_getheapsize',
        'sys_getlogin',
        'sys_getpid',
        'sys_getppid',
        'sys_getpwnam',
        'sys_getpwuid',
        'sys_getstartclock',
        'sys_getthreadcount',
        'sys_getuid',
        'sys_growheapby',
        'sys_homepath',
        'sys_is_full_path',
        'sys_is_windows',
        'sys_isfullpath',
        'sys_iswindows',
        'sys_iterate',
        'sys_jrand48',
        'sys_kill_exec',
        'sys_kill',
        'sys_lcong48',
        'sys_librariespath',
        'sys_listtraits',
        'sys_listtypes',
        'sys_listunboundmethods',
        'sys_loadlibrary',
        'sys_lrand48',
        'sys_masterhomepath',
        'sys_mrand48',
        'sys_nrand48',
        'sys_pid_exec',
        'sys_pointersize',
        'sys_rand',
        'sys_random',
        'sys_seed48',
        'sys_setenv',
        'sys_setgid',
        'sys_setsid',
        'sys_setuid',
        'sys_sigabrt',
        'sys_sigalrm',
        'sys_sigbus',
        'sys_sigchld',
        'sys_sigcont',
        'sys_sigfpe',
        'sys_sighup',
        'sys_sigill',
        'sys_sigint',
        'sys_sigkill',
        'sys_sigpipe',
        'sys_sigprof',
        'sys_sigquit',
        'sys_sigsegv',
        'sys_sigstop',
        'sys_sigsys',
        'sys_sigterm',
        'sys_sigtrap',
        'sys_sigtstp',
        'sys_sigttin',
        'sys_sigttou',
        'sys_sigurg',
        'sys_sigusr1',
        'sys_sigusr2',
        'sys_sigvtalrm',
        'sys_sigxcpu',
        'sys_sigxfsz',
        'sys_srand',
        'sys_srand48',
        'sys_srandom',
        'sys_strerror',
        'sys_supportpath',
        'sys_test_exec',
        'sys_time',
        'sys_uname',
        'sys_unsetenv',
        'sys_usercapimodulepath',
        'sys_userstartuppath',
        'sys_version',
        'sys_wait_exec',
        'sys_waitpid',
        'sys_wcontinued',
        'sys_while',
        'sys_wnohang',
        'sys_wuntraced',
        'table_name',
        'tag_exists',
        'tag_name',
        'thread_var_get',
        'thread_var_pop',
        'thread_var_push',
        'threadvar_find',
        'threadvar_get',
        'threadvar_set_asrt',
        'threadvar_set',
        'timer',
        'token_value',
        'treemap',
        'u_lb_alphabetic',
        'u_lb_ambiguous',
        'u_lb_break_after',
        'u_lb_break_before',
        'u_lb_break_both',
        'u_lb_break_symbols',
        'u_lb_carriage_return',
        'u_lb_close_punctuation',
        'u_lb_combining_mark',
        'u_lb_complex_context',
        'u_lb_contingent_break',
        'u_lb_exclamation',
        'u_lb_glue',
        'u_lb_h2',
        'u_lb_h3',
        'u_lb_hyphen',
        'u_lb_ideographic',
        'u_lb_infix_numeric',
        'u_lb_inseparable',
        'u_lb_jl',
        'u_lb_jt',
        'u_lb_jv',
        'u_lb_line_feed',
        'u_lb_mandatory_break',
        'u_lb_next_line',
        'u_lb_nonstarter',
        'u_lb_numeric',
        'u_lb_open_punctuation',
        'u_lb_postfix_numeric',
        'u_lb_prefix_numeric',
        'u_lb_quotation',
        'u_lb_space',
        'u_lb_surrogate',
        'u_lb_unknown',
        'u_lb_word_joiner',
        'u_lb_zwspace',
        'u_nt_decimal',
        'u_nt_digit',
        'u_nt_none',
        'u_nt_numeric',
        'u_sb_aterm',
        'u_sb_close',
        'u_sb_format',
        'u_sb_lower',
        'u_sb_numeric',
        'u_sb_oletter',
        'u_sb_other',
        'u_sb_sep',
        'u_sb_sp',
        'u_sb_sterm',
        'u_sb_upper',
        'u_wb_aletter',
        'u_wb_extendnumlet',
        'u_wb_format',
        'u_wb_katakana',
        'u_wb_midletter',
        'u_wb_midnum',
        'u_wb_numeric',
        'u_wb_other',
        'ucal_ampm',
        'ucal_dayofmonth',
        'ucal_dayofweek',
        'ucal_dayofweekinmonth',
        'ucal_dayofyear',
        'ucal_daysinfirstweek',
        'ucal_dowlocal',
        'ucal_dstoffset',
        'ucal_era',
        'ucal_extendedyear',
        'ucal_firstdayofweek',
        'ucal_hour',
        'ucal_hourofday',
        'ucal_julianday',
        'ucal_lenient',
        'ucal_listtimezones',
        'ucal_millisecond',
        'ucal_millisecondsinday',
        'ucal_minute',
        'ucal_month',
        'ucal_second',
        'ucal_weekofmonth',
        'ucal_weekofyear',
        'ucal_year',
        'ucal_yearwoy',
        'ucal_zoneoffset',
        'uchar_age',
        'uchar_alphabetic',
        'uchar_ascii_hex_digit',
        'uchar_bidi_class',
        'uchar_bidi_control',
        'uchar_bidi_mirrored',
        'uchar_bidi_mirroring_glyph',
        'uchar_block',
        'uchar_canonical_combining_class',
        'uchar_case_folding',
        'uchar_case_sensitive',
        'uchar_dash',
        'uchar_decomposition_type',
        'uchar_default_ignorable_code_point',
        'uchar_deprecated',
        'uchar_diacritic',
        'uchar_east_asian_width',
        'uchar_extender',
        'uchar_full_composition_exclusion',
        'uchar_general_category_mask',
        'uchar_general_category',
        'uchar_grapheme_base',
        'uchar_grapheme_cluster_break',
        'uchar_grapheme_extend',
        'uchar_grapheme_link',
        'uchar_hangul_syllable_type',
        'uchar_hex_digit',
        'uchar_hyphen',
        'uchar_id_continue',
        'uchar_ideographic',
        'uchar_ids_binary_operator',
        'uchar_ids_trinary_operator',
        'uchar_iso_comment',
        'uchar_join_control',
        'uchar_joining_group',
        'uchar_joining_type',
        'uchar_lead_canonical_combining_class',
        'uchar_line_break',
        'uchar_logical_order_exception',
        'uchar_lowercase_mapping',
        'uchar_lowercase',
        'uchar_math',
        'uchar_name',
        'uchar_nfc_inert',
        'uchar_nfc_quick_check',
        'uchar_nfd_inert',
        'uchar_nfd_quick_check',
        'uchar_nfkc_inert',
        'uchar_nfkc_quick_check',
        'uchar_nfkd_inert',
        'uchar_nfkd_quick_check',
        'uchar_noncharacter_code_point',
        'uchar_numeric_type',
        'uchar_numeric_value',
        'uchar_pattern_syntax',
        'uchar_pattern_white_space',
        'uchar_posix_alnum',
        'uchar_posix_blank',
        'uchar_posix_graph',
        'uchar_posix_print',
        'uchar_posix_xdigit',
        'uchar_quotation_mark',
        'uchar_radical',
        'uchar_s_term',
        'uchar_script',
        'uchar_segment_starter',
        'uchar_sentence_break',
        'uchar_simple_case_folding',
        'uchar_simple_lowercase_mapping',
        'uchar_simple_titlecase_mapping',
        'uchar_simple_uppercase_mapping',
        'uchar_soft_dotted',
        'uchar_terminal_punctuation',
        'uchar_titlecase_mapping',
        'uchar_trail_canonical_combining_class',
        'uchar_unicode_1_name',
        'uchar_unified_ideograph',
        'uchar_uppercase_mapping',
        'uchar_uppercase',
        'uchar_variation_selector',
        'uchar_white_space',
        'uchar_word_break',
        'uchar_xid_continue',
        'uncompress',
        'usage',
        'uuid_compare',
        'uuid_copy',
        'uuid_generate_random',
        'uuid_generate_time',
        'uuid_generate',
        'uuid_is_null',
        'uuid_parse',
        'uuid_unparse_lower',
        'uuid_unparse_upper',
        'uuid_unparse',
        'value_list',
        'value_listitem',
        'valuelistitem',
        'var_keys',
        'var_values',
        'wap_isenabled',
        'wap_maxbuttons',
        'wap_maxcolumns',
        'wap_maxhorzpixels',
        'wap_maxrows',
        'wap_maxvertpixels',
        'web_handlefcgirequest',
        'web_node_content_representation_css',
        'web_node_content_representation_html',
        'web_node_content_representation_js',
        'web_node_content_representation_xhr',
        'web_node_forpath',
        'web_nodes_initialize',
        'web_nodes_normalizeextension',
        'web_nodes_processcontentnode',
        'web_nodes_requesthandler',
        'web_response_nodesentry',
        'web_router_database',
        'web_router_initialize',
        'websocket_handler_timeout',
        'wexitstatus',
        'wifcontinued',
        'wifexited',
        'wifsignaled',
        'wifstopped',
        'wstopsig',
        'wtermsig',
        'xml_transform',
        'xml',
        'zip_add_dir',
        'zip_add',
        'zip_checkcons',
        'zip_close',
        'zip_cm_bzip2',
        'zip_cm_default',
        'zip_cm_deflate',
        'zip_cm_deflate64',
        'zip_cm_implode',
        'zip_cm_pkware_implode',
        'zip_cm_reduce_1',
        'zip_cm_reduce_2',
        'zip_cm_reduce_3',
        'zip_cm_reduce_4',
        'zip_cm_shrink',
        'zip_cm_store',
        'zip_create',
        'zip_delete',
        'zip_em_3des_112',
        'zip_em_3des_168',
        'zip_em_aes_128',
        'zip_em_aes_192',
        'zip_em_aes_256',
        'zip_em_des',
        'zip_em_none',
        'zip_em_rc2_old',
        'zip_em_rc2',
        'zip_em_rc4',
        'zip_em_trad_pkware',
        'zip_em_unknown',
        'zip_er_changed',
        'zip_er_close',
        'zip_er_compnotsupp',
        'zip_er_crc',
        'zip_er_deleted',
        'zip_er_eof',
        'zip_er_exists',
        'zip_er_incons',
        'zip_er_internal',
        'zip_er_inval',
        'zip_er_memory',
        'zip_er_multidisk',
        'zip_er_noent',
        'zip_er_nozip',
        'zip_er_ok',
        'zip_er_open',
        'zip_er_read',
        'zip_er_remove',
        'zip_er_rename',
        'zip_er_seek',
        'zip_er_tmpopen',
        'zip_er_write',
        'zip_er_zipclosed',
        'zip_er_zlib',
        'zip_error_get_sys_type',
        'zip_error_get',
        'zip_error_to_str',
        'zip_et_none',
        'zip_et_sys',
        'zip_et_zlib',
        'zip_excl',
        'zip_fclose',
        'zip_file_error_get',
        'zip_file_strerror',
        'zip_fl_compressed',
        'zip_fl_nocase',
        'zip_fl_nodir',
        'zip_fl_unchanged',
        'zip_fopen_index',
        'zip_fopen',
        'zip_fread',
        'zip_get_archive_comment',
        'zip_get_file_comment',
        'zip_get_name',
        'zip_get_num_files',
        'zip_name_locate',
        'zip_open',
        'zip_rename',
        'zip_replace',
        'zip_set_archive_comment',
        'zip_set_file_comment',
        'zip_stat_index',
        'zip_stat',
        'zip_strerror',
        'zip_unchange_all',
        'zip_unchange_archive',
        'zip_unchange',
        'zlib_version',
    ),
    'Lasso 8 Tags': (
        '__char',
        '__sync_timestamp__',
        '_admin_addgroup',
        '_admin_adduser',
        '_admin_defaultconnector',
        '_admin_defaultconnectornames',
        '_admin_defaultdatabase',
        '_admin_defaultfield',
        '_admin_defaultgroup',
        '_admin_defaulthost',
        '_admin_defaulttable',
        '_admin_defaultuser',
        '_admin_deleteconnector',
        '_admin_deletedatabase',
        '_admin_deletefield',
        '_admin_deletegroup',
        '_admin_deletehost',
        '_admin_deletetable',
        '_admin_deleteuser',
        '_admin_duplicategroup',
        '_admin_internaldatabase',
        '_admin_listconnectors',
        '_admin_listdatabases',
        '_admin_listfields',
        '_admin_listgroups',
        '_admin_listhosts',
        '_admin_listtables',
        '_admin_listusers',
        '_admin_refreshconnector',
        '_admin_refreshsecurity',
        '_admin_servicepath',
        '_admin_updateconnector',
        '_admin_updatedatabase',
        '_admin_updatefield',
        '_admin_updategroup',
        '_admin_updatehost',
        '_admin_updatetable',
        '_admin_updateuser',
        '_chartfx_activation_string',
        '_chartfx_getchallengestring',
        '_chop_args',
        '_chop_mimes',
        '_client_addr_old',
        '_client_address_old',
        '_client_ip_old',
        '_database_names',
        '_datasource_reload',
        '_date_current',
        '_date_format',
        '_date_msec',
        '_date_parse',
        '_execution_timelimit',
        '_file_chmod',
        '_initialize',
        '_jdbc_acceptsurl',
        '_jdbc_debug',
        '_jdbc_deletehost',
        '_jdbc_driverclasses',
        '_jdbc_driverinfo',
        '_jdbc_metainfo',
        '_jdbc_propertyinfo',
        '_jdbc_setdriver',
        '_lasso_param',
        '_log_helper',
        '_proc_noparam',
        '_proc_withparam',
        '_recursion_limit',
        '_request_param',
        '_security_binaryexpiration',
        '_security_flushcaches',
        '_security_isserialized',
        '_security_serialexpiration',
        '_srand',
        '_strict_literals',
        '_substring',
        '_xmlrpc_exconverter',
        '_xmlrpc_inconverter',
        '_xmlrpc_xmlinconverter',
        'abort',
        'action_addinfo',
        'action_addrecord',
        'action_param',
        'action_params',
        'action_setfoundcount',
        'action_setrecordid',
        'action_settotalcount',
        'action_statement',
        'admin_allowedfileroots',
        'admin_changeuser',
        'admin_createuser',
        'admin_currentgroups',
        'admin_currentuserid',
        'admin_currentusername',
        'admin_getpref',
        'admin_groupassignuser',
        'admin_grouplistusers',
        'admin_groupremoveuser',
        'admin_lassoservicepath',
        'admin_listgroups',
        'admin_refreshlicensing',
        'admin_refreshsecurity',
        'admin_reloaddatasource',
        'admin_removepref',
        'admin_setpref',
        'admin_userexists',
        'admin_userlistgroups',
        'all',
        'and',
        'array',
        'array_iterator',
        'auth',
        'auth_admin',
        'auth_auth',
        'auth_custom',
        'auth_group',
        'auth_prompt',
        'auth_user',
        'base64',
        'bean',
        'bigint',
        'bom_utf16be',
        'bom_utf16le',
        'bom_utf32be',
        'bom_utf32le',
        'bom_utf8',
        'boolean',
        'bw',
        'bytes',
        'cache',
        'cache_delete',
        'cache_empty',
        'cache_exists',
        'cache_fetch',
        'cache_internal',
        'cache_maintenance',
        'cache_object',
        'cache_preferences',
        'cache_store',
        'case',
        'chartfx',
        'chartfx_records',
        'chartfx_serve',
        'checked',
        'choice_list',
        'choice_listitem',
        'choicelistitem',
        'cipher_decrypt',
        'cipher_digest',
        'cipher_encrypt',
        'cipher_hmac',
        'cipher_keylength',
        'cipher_list',
        'click_text',
        'client_addr',
        'client_address',
        'client_authorization',
        'client_browser',
        'client_contentlength',
        'client_contenttype',
        'client_cookielist',
        'client_cookies',
        'client_encoding',
        'client_formmethod',
        'client_getargs',
        'client_getparams',
        'client_headers',
        'client_ip',
        'client_ipfrominteger',
        'client_iptointeger',
        'client_password',
        'client_postargs',
        'client_postparams',
        'client_type',
        'client_url',
        'client_username',
        'cn',
        'column',
        'column_name',
        'column_names',
        'compare_beginswith',
        'compare_contains',
        'compare_endswith',
        'compare_equalto',
        'compare_greaterthan',
        'compare_greaterthanorequals',
        'compare_greaterthanorequls',
        'compare_lessthan',
        'compare_lessthanorequals',
        'compare_notbeginswith',
        'compare_notcontains',
        'compare_notendswith',
        'compare_notequalto',
        'compare_notregexp',
        'compare_regexp',
        'compare_strictequalto',
        'compare_strictnotequalto',
        'compiler_removecacheddoc',
        'compiler_setdefaultparserflags',
        'compress',
        'content_body',
        'content_encoding',
        'content_header',
        'content_type',
        'cookie',
        'cookie_set',
        'curl_ftp_getfile',
        'curl_ftp_getlisting',
        'curl_ftp_putfile',
        'curl_include_url',
        'currency',
        'database_changecolumn',
        'database_changefield',
        'database_createcolumn',
        'database_createfield',
        'database_createtable',
        'database_fmcontainer',
        'database_hostinfo',
        'database_inline',
        'database_name',
        'database_nameitem',
        'database_names',
        'database_realname',
        'database_removecolumn',
        'database_removefield',
        'database_removetable',
        'database_repeating',
        'database_repeating_valueitem',
        'database_repeatingvalueitem',
        'database_schemanameitem',
        'database_schemanames',
        'database_tablecolumn',
        'database_tablenameitem',
        'database_tablenames',
        'datasource_name',
        'datasource_register',
        'date',
        'date__date_current',
        'date__date_format',
        'date__date_msec',
        'date__date_parse',
        'date_add',
        'date_date',
        'date_difference',
        'date_duration',
        'date_format',
        'date_getcurrentdate',
        'date_getday',
        'date_getdayofweek',
        'date_gethour',
        'date_getlocaltimezone',
        'date_getminute',
        'date_getmonth',
        'date_getsecond',
        'date_gettime',
        'date_getyear',
        'date_gmttolocal',
        'date_localtogmt',
        'date_maximum',
        'date_minimum',
        'date_msec',
        'date_setformat',
        'date_subtract',
        'db_layoutnameitem',
        'db_layoutnames',
        'db_nameitem',
        'db_names',
        'db_tablenameitem',
        'db_tablenames',
        'dbi_column_names',
        'dbi_field_names',
        'decimal',
        'decimal_setglobaldefaultprecision',
        'decode_base64',
        'decode_bheader',
        'decode_hex',
        'decode_html',
        'decode_json',
        'decode_qheader',
        'decode_quotedprintable',
        'decode_quotedprintablebytes',
        'decode_url',
        'decode_xml',
        'decompress',
        'decrypt_blowfish',
        'decrypt_blowfish2',
        'default',
        'define_atbegin',
        'define_atend',
        'define_constant',
        'define_prototype',
        'define_tag',
        'define_tagp',
        'define_type',
        'define_typep',
        'deserialize',
        'directory_directorynameitem',
        'directory_lister',
        'directory_nameitem',
        'directorynameitem',
        'dns_default',
        'dns_lookup',
        'dns_response',
        'duration',
        'else',
        'email_batch',
        'email_compose',
        'email_digestchallenge',
        'email_digestresponse',
        'email_extract',
        'email_findemails',
        'email_immediate',
        'email_merge',
        'email_mxerror',
        'email_mxlookup',
        'email_parse',
        'email_pop',
        'email_queue',
        'email_result',
        'email_safeemail',
        'email_send',
        'email_smtp',
        'email_status',
        'email_token',
        'email_translatebreakstocrlf',
        'encode_base64',
        'encode_bheader',
        'encode_break',
        'encode_breaks',
        'encode_crc32',
        'encode_hex',
        'encode_html',
        'encode_htmltoxml',
        'encode_json',
        'encode_qheader',
        'encode_quotedprintable',
        'encode_quotedprintablebytes',
        'encode_set',
        'encode_smart',
        'encode_sql',
        'encode_sql92',
        'encode_stricturl',
        'encode_url',
        'encode_xml',
        'encrypt_blowfish',
        'encrypt_blowfish2',
        'encrypt_crammd5',
        'encrypt_hmac',
        'encrypt_md5',
        'eq',
        'error_adderror',
        'error_code',
        'error_code_aborted',
        'error_code_assert',
        'error_code_bof',
        'error_code_connectioninvalid',
        'error_code_couldnotclosefile',
        'error_code_couldnotcreateoropenfile',
        'error_code_couldnotdeletefile',
        'error_code_couldnotdisposememory',
        'error_code_couldnotlockmemory',
        'error_code_couldnotreadfromfile',
        'error_code_couldnotunlockmemory',
        'error_code_couldnotwritetofile',
        'error_code_criterianotmet',
        'error_code_datasourceerror',
        'error_code_directoryfull',
        'error_code_diskfull',
        'error_code_dividebyzero',
        'error_code_eof',
        'error_code_failure',
        'error_code_fieldrestriction',
        'error_code_file',
        'error_code_filealreadyexists',
        'error_code_filecorrupt',
        'error_code_fileinvalid',
        'error_code_fileinvalidaccessmode',
        'error_code_fileisclosed',
        'error_code_fileisopen',
        'error_code_filelocked',
        'error_code_filenotfound',
        'error_code_fileunlocked',
        'error_code_httpfilenotfound',
        'error_code_illegalinstruction',
        'error_code_illegaluseoffrozeninstance',
        'error_code_invaliddatabase',
        'error_code_invalidfilename',
        'error_code_invalidmemoryobject',
        'error_code_invalidparameter',
        'error_code_invalidpassword',
        'error_code_invalidpathname',
        'error_code_invalidusername',
        'error_code_ioerror',
        'error_code_loopaborted',
        'error_code_memory',
        'error_code_network',
        'error_code_nilpointer',
        'error_code_noerr',
        'error_code_nopermission',
        'error_code_outofmemory',
        'error_code_outofstackspace',
        'error_code_overflow',
        'error_code_postconditionfailed',
        'error_code_preconditionfailed',
        'error_code_resnotfound',
        'error_code_resource',
        'error_code_streamreaderror',
        'error_code_streamwriteerror',
        'error_code_syntaxerror',
        'error_code_tagnotfound',
        'error_code_unknownerror',
        'error_code_varnotfound',
        'error_code_volumedoesnotexist',
        'error_code_webactionnotsupported',
        'error_code_webadderror',
        'error_code_webdeleteerror',
        'error_code_webmodulenotfound',
        'error_code_webnosuchobject',
        'error_code_webrepeatingrelatedfield',
        'error_code_webrequiredfieldmissing',
        'error_code_webtimeout',
        'error_code_webupdateerror',
        'error_columnrestriction',
        'error_currenterror',
        'error_databaseconnectionunavailable',
        'error_databasetimeout',
        'error_deleteerror',
        'error_fieldrestriction',
        'error_filenotfound',
        'error_invaliddatabase',
        'error_invalidpassword',
        'error_invalidusername',
        'error_modulenotfound',
        'error_msg',
        'error_msg_aborted',
        'error_msg_assert',
        'error_msg_bof',
        'error_msg_connectioninvalid',
        'error_msg_couldnotclosefile',
        'error_msg_couldnotcreateoropenfile',
        'error_msg_couldnotdeletefile',
        'error_msg_couldnotdisposememory',
        'error_msg_couldnotlockmemory',
        'error_msg_couldnotreadfromfile',
        'error_msg_couldnotunlockmemory',
        'error_msg_couldnotwritetofile',
        'error_msg_criterianotmet',
        'error_msg_datasourceerror',
        'error_msg_directoryfull',
        'error_msg_diskfull',
        'error_msg_dividebyzero',
        'error_msg_eof',
        'error_msg_failure',
        'error_msg_fieldrestriction',
        'error_msg_file',
        'error_msg_filealreadyexists',
        'error_msg_filecorrupt',
        'error_msg_fileinvalid',
        'error_msg_fileinvalidaccessmode',
        'error_msg_fileisclosed',
        'error_msg_fileisopen',
        'error_msg_filelocked',
        'error_msg_filenotfound',
        'error_msg_fileunlocked',
        'error_msg_httpfilenotfound',
        'error_msg_illegalinstruction',
        'error_msg_illegaluseoffrozeninstance',
        'error_msg_invaliddatabase',
        'error_msg_invalidfilename',
        'error_msg_invalidmemoryobject',
        'error_msg_invalidparameter',
        'error_msg_invalidpassword',
        'error_msg_invalidpathname',
        'error_msg_invalidusername',
        'error_msg_ioerror',
        'error_msg_loopaborted',
        'error_msg_memory',
        'error_msg_network',
        'error_msg_nilpointer',
        'error_msg_noerr',
        'error_msg_nopermission',
        'error_msg_outofmemory',
        'error_msg_outofstackspace',
        'error_msg_overflow',
        'error_msg_postconditionfailed',
        'error_msg_preconditionfailed',
        'error_msg_resnotfound',
        'error_msg_resource',
        'error_msg_streamreaderror',
        'error_msg_streamwriteerror',
        'error_msg_syntaxerror',
        'error_msg_tagnotfound',
        'error_msg_unknownerror',
        'error_msg_varnotfound',
        'error_msg_volumedoesnotexist',
        'error_msg_webactionnotsupported',
        'error_msg_webadderror',
        'error_msg_webdeleteerror',
        'error_msg_webmodulenotfound',
        'error_msg_webnosuchobject',
        'error_msg_webrepeatingrelatedfield',
        'error_msg_webrequiredfieldmissing',
        'error_msg_webtimeout',
        'error_msg_webupdateerror',
        'error_noerror',
        'error_nopermission',
        'error_norecordsfound',
        'error_outofmemory',
        'error_pop',
        'error_push',
        'error_reqcolumnmissing',
        'error_reqfieldmissing',
        'error_requiredcolumnmissing',
        'error_requiredfieldmissing',
        'error_reset',
        'error_seterrorcode',
        'error_seterrormessage',
        'error_updateerror',
        'euro',
        'event_schedule',
        'ew',
        'fail',
        'fail_if',
        'false',
        'field',
        'field_name',
        'field_names',
        'file',
        'file_autoresolvefullpaths',
        'file_chmod',
        'file_control',
        'file_copy',
        'file_create',
        'file_creationdate',
        'file_currenterror',
        'file_delete',
        'file_exists',
        'file_getlinecount',
        'file_getsize',
        'file_isdirectory',
        'file_listdirectory',
        'file_moddate',
        'file_modechar',
        'file_modeline',
        'file_move',
        'file_openread',
        'file_openreadwrite',
        'file_openwrite',
        'file_openwriteappend',
        'file_openwritetruncate',
        'file_probeeol',
        'file_processuploads',
        'file_read',
        'file_readline',
        'file_rename',
        'file_serve',
        'file_setsize',
        'file_stream',
        'file_streamcopy',
        'file_uploads',
        'file_waitread',
        'file_waittimeout',
        'file_waitwrite',
        'file_write',
        'find_soap_ops',
        'form_param',
        'found_count',
        'ft',
        'ftp_getfile',
        'ftp_getlisting',
        'ftp_putfile',
        'full',
        'global',
        'global_defined',
        'global_remove',
        'global_reset',
        'globals',
        'gt',
        'gte',
        'handle',
        'handle_error',
        'header',
        'html_comment',
        'http_getfile',
        'ical_alarm',
        'ical_attribute',
        'ical_calendar',
        'ical_daylight',
        'ical_event',
        'ical_freebusy',
        'ical_item',
        'ical_journal',
        'ical_parse',
        'ical_standard',
        'ical_timezone',
        'ical_todo',
        'if',
        'if_empty',
        'if_false',
        'if_null',
        'if_true',
        'image',
        'image_url',
        'img',
        'include',
        'include_cgi',
        'include_currentpath',
        'include_once',
        'include_raw',
        'include_url',
        'inline',
        'integer',
        'iterate',
        'iterator',
        'java',
        'java_bean',
        'json_records',
        'json_rpccall',
        'keycolumn_name',
        'keycolumn_value',
        'keyfield_name',
        'keyfield_value',
        'lasso_comment',
        'lasso_currentaction',
        'lasso_datasourceis',
        'lasso_datasourceis4d',
        'lasso_datasourceisfilemaker',
        'lasso_datasourceisfilemaker7',
        'lasso_datasourceisfilemaker9',
        'lasso_datasourceisfilemakersa',
        'lasso_datasourceisjdbc',
        'lasso_datasourceislassomysql',
        'lasso_datasourceismysql',
        'lasso_datasourceisodbc',
        'lasso_datasourceisopenbase',
        'lasso_datasourceisoracle',
        'lasso_datasourceispostgresql',
        'lasso_datasourceisspotlight',
        'lasso_datasourceissqlite',
        'lasso_datasourceissqlserver',
        'lasso_datasourcemodulename',
        'lasso_datatype',
        'lasso_disableondemand',
        'lasso_errorreporting',
        'lasso_executiontimelimit',
        'lasso_parser',
        'lasso_process',
        'lasso_sessionid',
        'lasso_siteid',
        'lasso_siteisrunning',
        'lasso_sitename',
        'lasso_siterestart',
        'lasso_sitestart',
        'lasso_sitestop',
        'lasso_tagexists',
        'lasso_tagmodulename',
        'lasso_uniqueid',
        'lasso_updatecheck',
        'lasso_uptime',
        'lasso_version',
        'lassoapp_create',
        'lassoapp_dump',
        'lassoapp_flattendir',
        'lassoapp_getappdata',
        'lassoapp_link',
        'lassoapp_list',
        'lassoapp_process',
        'lassoapp_unitize',
        'layout_name',
        'ldap',
        'ldap_scope_base',
        'ldap_scope_onelevel',
        'ldap_scope_subtree',
        'ldml',
        'ldml_ldml',
        'library',
        'library_once',
        'link',
        'link_currentaction',
        'link_currentactionparams',
        'link_currentactionurl',
        'link_currentgroup',
        'link_currentgroupparams',
        'link_currentgroupurl',
        'link_currentrecord',
        'link_currentrecordparams',
        'link_currentrecordurl',
        'link_currentsearch',
        'link_currentsearchparams',
        'link_currentsearchurl',
        'link_detail',
        'link_detailparams',
        'link_detailurl',
        'link_firstgroup',
        'link_firstgroupparams',
        'link_firstgroupurl',
        'link_firstrecord',
        'link_firstrecordparams',
        'link_firstrecordurl',
        'link_lastgroup',
        'link_lastgroupparams',
        'link_lastgroupurl',
        'link_lastrecord',
        'link_lastrecordparams',
        'link_lastrecordurl',
        'link_nextgroup',
        'link_nextgroupparams',
        'link_nextgroupurl',
        'link_nextrecord',
        'link_nextrecordparams',
        'link_nextrecordurl',
        'link_params',
        'link_prevgroup',
        'link_prevgroupparams',
        'link_prevgroupurl',
        'link_prevrecord',
        'link_prevrecordparams',
        'link_prevrecordurl',
        'link_setformat',
        'link_url',
        'list',
        'list_additem',
        'list_fromlist',
        'list_fromstring',
        'list_getitem',
        'list_itemcount',
        'list_iterator',
        'list_removeitem',
        'list_replaceitem',
        'list_reverseiterator',
        'list_tostring',
        'literal',
        'ljax_end',
        'ljax_hastarget',
        'ljax_include',
        'ljax_start',
        'ljax_target',
        'local',
        'local_defined',
        'local_remove',
        'local_reset',
        'locale_format',
        'locals',
        'log',
        'log_always',
        'log_critical',
        'log_deprecated',
        'log_destination_console',
        'log_destination_database',
        'log_destination_file',
        'log_detail',
        'log_level_critical',
        'log_level_deprecated',
        'log_level_detail',
        'log_level_sql',
        'log_level_warning',
        'log_setdestination',
        'log_sql',
        'log_warning',
        'logicalop_value',
        'logicaloperator_value',
        'loop',
        'loop_abort',
        'loop_continue',
        'loop_count',
        'lt',
        'lte',
        'magick_image',
        'map',
        'map_iterator',
        'match_comparator',
        'match_notrange',
        'match_notregexp',
        'match_range',
        'match_regexp',
        'math_abs',
        'math_acos',
        'math_add',
        'math_asin',
        'math_atan',
        'math_atan2',
        'math_ceil',
        'math_converteuro',
        'math_cos',
        'math_div',
        'math_exp',
        'math_floor',
        'math_internal_rand',
        'math_internal_randmax',
        'math_internal_srand',
        'math_ln',
        'math_log',
        'math_log10',
        'math_max',
        'math_min',
        'math_mod',
        'math_mult',
        'math_pow',
        'math_random',
        'math_range',
        'math_rint',
        'math_roman',
        'math_round',
        'math_sin',
        'math_sqrt',
        'math_sub',
        'math_tan',
        'maxrecords_value',
        'memory_session_driver',
        'mime_type',
        'minimal',
        'misc__srand',
        'misc_randomnumber',
        'misc_roman',
        'misc_valid_creditcard',
        'mysql_session_driver',
        'named_param',
        'namespace_current',
        'namespace_delimiter',
        'namespace_exists',
        'namespace_file_fullpathexists',
        'namespace_global',
        'namespace_import',
        'namespace_load',
        'namespace_page',
        'namespace_unload',
        'namespace_using',
        'neq',
        'net',
        'net_connectinprogress',
        'net_connectok',
        'net_typessl',
        'net_typessltcp',
        'net_typessludp',
        'net_typetcp',
        'net_typeudp',
        'net_waitread',
        'net_waittimeout',
        'net_waitwrite',
        'no_default_output',
        'none',
        'noprocess',
        'not',
        'nrx',
        'nslookup',
        'null',
        'object',
        'once',
        'oneoff',
        'op_logicalvalue',
        'operator_logicalvalue',
        'option',
        'or',
        'os_process',
        'output',
        'output_none',
        'pair',
        'params_up',
        'pdf_barcode',
        'pdf_color',
        'pdf_doc',
        'pdf_font',
        'pdf_image',
        'pdf_list',
        'pdf_read',
        'pdf_serve',
        'pdf_table',
        'pdf_text',
        'percent',
        'portal',
        'postcondition',
        'precondition',
        'prettyprintingnsmap',
        'prettyprintingtypemap',
        'priorityqueue',
        'private',
        'proc_convert',
        'proc_convertbody',
        'proc_convertone',
        'proc_extract',
        'proc_extractone',
        'proc_find',
        'proc_first',
        'proc_foreach',
        'proc_get',
        'proc_join',
        'proc_lasso',
        'proc_last',
        'proc_map_entry',
        'proc_null',
        'proc_regexp',
        'proc_xml',
        'proc_xslt',
        'process',
        'protect',
        'queue',
        'rand',
        'randomnumber',
        'raw',
        'recid_value',
        'record_count',
        'recordcount',
        'recordid_value',
        'records',
        'records_array',
        'records_map',
        'redirect_url',
        'reference',
        'referer',
        'referer_url',
        'referrer',
        'referrer_url',
        'regexp',
        'repeating',
        'repeating_valueitem',
        'repeatingvalueitem',
        'repetition',
        'req_column',
        'req_field',
        'required_column',
        'required_field',
        'response_fileexists',
        'response_filepath',
        'response_localpath',
        'response_path',
        'response_realm',
        'resultset',
        'resultset_count',
        'return',
        'return_value',
        'reverseiterator',
        'roman',
        'row_count',
        'rows',
        'rows_array',
        'run_children',
        'rx',
        'schema_name',
        'scientific',
        'search_args',
        'search_arguments',
        'search_columnitem',
        'search_fielditem',
        'search_operatoritem',
        'search_opitem',
        'search_valueitem',
        'searchfielditem',
        'searchoperatoritem',
        'searchopitem',
        'searchvalueitem',
        'select',
        'selected',
        'self',
        'serialize',
        'series',
        'server_date',
        'server_day',
        'server_ip',
        'server_name',
        'server_port',
        'server_push',
        'server_siteisrunning',
        'server_sitestart',
        'server_sitestop',
        'server_time',
        'session_abort',
        'session_addoutputfilter',
        'session_addvar',
        'session_addvariable',
        'session_deleteexpired',
        'session_driver',
        'session_end',
        'session_id',
        'session_removevar',
        'session_removevariable',
        'session_result',
        'session_setdriver',
        'session_start',
        'set',
        'set_iterator',
        'set_reverseiterator',
        'shown_count',
        'shown_first',
        'shown_last',
        'site_atbegin',
        'site_id',
        'site_name',
        'site_restart',
        'skiprecords_value',
        'sleep',
        'soap_convertpartstopairs',
        'soap_definetag',
        'soap_info',
        'soap_lastrequest',
        'soap_lastresponse',
        'soap_stub',
        'sort_args',
        'sort_arguments',
        'sort_columnitem',
        'sort_fielditem',
        'sort_orderitem',
        'sortcolumnitem',
        'sortfielditem',
        'sortorderitem',
        'sqlite_createdb',
        'sqlite_session_driver',
        'sqlite_setsleepmillis',
        'sqlite_setsleeptries',
        'srand',
        'stack',
        'stock_quote',
        'string',
        'string_charfromname',
        'string_concatenate',
        'string_countfields',
        'string_endswith',
        'string_extract',
        'string_findposition',
        'string_findregexp',
        'string_fordigit',
        'string_getfield',
        'string_getunicodeversion',
        'string_insert',
        'string_isalpha',
        'string_isalphanumeric',
        'string_isdigit',
        'string_ishexdigit',
        'string_islower',
        'string_isnumeric',
        'string_ispunctuation',
        'string_isspace',
        'string_isupper',
        'string_length',
        'string_lowercase',
        'string_remove',
        'string_removeleading',
        'string_removetrailing',
        'string_replace',
        'string_replaceregexp',
        'string_todecimal',
        'string_tointeger',
        'string_uppercase',
        'string_validcharset',
        'table_name',
        'table_realname',
        'tag',
        'tag_name',
        'tags',
        'tags_find',
        'tags_list',
        'tcp_close',
        'tcp_open',
        'tcp_send',
        'tcp_tcp_close',
        'tcp_tcp_open',
        'tcp_tcp_send',
        'thread_abort',
        'thread_atomic',
        'thread_event',
        'thread_exists',
        'thread_getcurrentid',
        'thread_getpriority',
        'thread_info',
        'thread_list',
        'thread_lock',
        'thread_pipe',
        'thread_priority_default',
        'thread_priority_high',
        'thread_priority_low',
        'thread_rwlock',
        'thread_semaphore',
        'thread_setpriority',
        'token_value',
        'total_records',
        'treemap',
        'treemap_iterator',
        'true',
        'url_rewrite',
        'valid_creditcard',
        'valid_date',
        'valid_email',
        'valid_url',
        'value_list',
        'value_listitem',
        'valuelistitem',
        'var',
        'var_defined',
        'var_remove',
        'var_reset',
        'var_set',
        'variable',
        'variable_defined',
        'variable_set',
        'variables',
        'variant_count',
        'vars',
        'wap_isenabled',
        'wap_maxbuttons',
        'wap_maxcolumns',
        'wap_maxhorzpixels',
        'wap_maxrows',
        'wap_maxvertpixels',
        'while',
        'wsdl_extract',
        'wsdl_getbinding',
        'wsdl_getbindingforoperation',
        'wsdl_getbindingoperations',
        'wsdl_getmessagenamed',
        'wsdl_getmessageparts',
        'wsdl_getmessagetriofromporttype',
        'wsdl_getopbodystyle',
        'wsdl_getopbodyuse',
        'wsdl_getoperation',
        'wsdl_getoplocation',
        'wsdl_getopmessagetypes',
        'wsdl_getopsoapaction',
        'wsdl_getportaddress',
        'wsdl_getportsforservice',
        'wsdl_getporttype',
        'wsdl_getporttypeoperation',
        'wsdl_getservicedocumentation',
        'wsdl_getservices',
        'wsdl_gettargetnamespace',
        'wsdl_issoapoperation',
        'wsdl_listoperations',
        'wsdl_maketest',
        'xml',
        'xml_extract',
        'xml_rpc',
        'xml_rpccall',
        'xml_rw',
        'xml_serve',
        'xml_transform',
        'xml_xml',
        'xml_xmlstream',
        'xmlstream',
        'xsd_attribute',
        'xsd_blankarraybase',
        'xsd_blankbase',
        'xsd_buildtype',
        'xsd_cache',
        'xsd_checkcardinality',
        'xsd_continueall',
        'xsd_continueannotation',
        'xsd_continueany',
        'xsd_continueanyattribute',
        'xsd_continueattribute',
        'xsd_continueattributegroup',
        'xsd_continuechoice',
        'xsd_continuecomplexcontent',
        'xsd_continuecomplextype',
        'xsd_continuedocumentation',
        'xsd_continueextension',
        'xsd_continuegroup',
        'xsd_continuekey',
        'xsd_continuelist',
        'xsd_continuerestriction',
        'xsd_continuesequence',
        'xsd_continuesimplecontent',
        'xsd_continuesimpletype',
        'xsd_continueunion',
        'xsd_deserialize',
        'xsd_fullyqualifyname',
        'xsd_generate',
        'xsd_generateblankfromtype',
        'xsd_generateblanksimpletype',
        'xsd_generatetype',
        'xsd_getschematype',
        'xsd_issimpletype',
        'xsd_loadschema',
        'xsd_lookupnamespaceuri',
        'xsd_lookuptype',
        'xsd_processany',
        'xsd_processattribute',
        'xsd_processattributegroup',
        'xsd_processcomplextype',
        'xsd_processelement',
        'xsd_processgroup',
        'xsd_processimport',
        'xsd_processinclude',
        'xsd_processschema',
        'xsd_processsimpletype',
        'xsd_ref',
        'xsd_type',
    )
}
MEMBERS = {
    'Member Methods': (
        'abort',
        'abs',
        'accept_charset',
        'accept',
        'acceptconnections',
        'acceptdeserializedelement',
        'acceptnossl',
        'acceptpost',
        'accesskey',
        'acos',
        'acosh',
        'action',
        'actionparams',
        'active_tick',
        'add',
        'addatend',
        'addattachment',
        'addbarcode',
        'addchapter',
        'addcheckbox',
        'addcolumninfo',
        'addcombobox',
        'addcomment',
        'addcomponent',
        'addcomponents',
        'addcss',
        'adddatabasetable',
        'adddatasource',
        'adddatasourcedatabase',
        'adddatasourcehost',
        'adddir',
        'adddirpath',
        'addendjs',
        'addendjstext',
        'adderror',
        'addfavicon',
        'addfile',
        'addgroup',
        'addheader',
        'addhiddenfield',
        'addhtmlpart',
        'addimage',
        'addjavascript',
        'addjs',
        'addjstext',
        'addlist',
        'addmathfunctions',
        'addmember',
        'addoneheaderline',
        'addpage',
        'addparagraph',
        'addpart',
        'addpasswordfield',
        'addphrase',
        'addpostdispatch',
        'addpredispatch',
        'addradiobutton',
        'addradiogroup',
        'addresetbutton',
        'addrow',
        'addsection',
        'addselectlist',
        'addset',
        'addsubmitbutton',
        'addsubnode',
        'addtable',
        'addtask',
        'addtext',
        'addtextarea',
        'addtextfield',
        'addtextpart',
        'addtobuffer',
        'addtrait',
        'adduser',
        'addusertogroup',
        'addwarning',
        'addzip',
        'allocobject',
        'am',
        'ampm',
        'annotate',
        'answer',
        'apop',
        'append',
        'appendarray',
        'appendarraybegin',
        'appendarrayend',
        'appendbool',
        'appendbytes',
        'appendchar',
        'appendchild',
        'appendcolon',
        'appendcomma',
        'appenddata',
        'appenddatetime',
        'appenddbpointer',
        'appenddecimal',
        'appenddocument',
        'appendimagetolist',
        'appendinteger',
        'appendnowutc',
        'appendnull',
        'appendoid',
        'appendregex',
        'appendreplacement',
        'appendstring',
        'appendtail',
        'appendtime',
        'applyheatcolors',
        'appmessage',
        'appname',
        'appprefix',
        'appstatus',
        'arc',
        'archive',
        'arguments',
        'argumentvalue',
        'asarray',
        'asarraystring',
        'asasync',
        'asbytes',
        'ascopy',
        'ascopydeep',
        'asdecimal',
        'asgenerator',
        'asin',
        'asinh',
        'asinteger',
        'askeyedgenerator',
        'aslazystring',
        'aslist',
        'asraw',
        'asstaticarray',
        'asstring',
        'asstringhex',
        'asstringoct',
        'asxml',
        'atan',
        'atan2',
        'atanh',
        'atend',
        'atends',
        'atime',
        'attributecount',
        'attributes',
        'attrs',
        'auth',
        'authenticate',
        'authorize',
        'autocollectbuffer',
        'average',
        'back',
        'basename',
        'basepaths',
        'baseuri',
        'bcc',
        'beginssl',
        'beginswith',
        'begintls',
        'bestcharset',
        'bind_blob',
        'bind_double',
        'bind_int',
        'bind_null',
        'bind_parameter_index',
        'bind_text',
        'bind',
        'bindcount',
        'bindone',
        'bindparam',
        'bitand',
        'bitclear',
        'bitflip',
        'bitformat',
        'bitnot',
        'bitor',
        'bitset',
        'bitshiftleft',
        'bitshiftright',
        'bittest',
        'bitxor',
        'blur',
        'body',
        'bodybytes',
        'boundary',
        'bptoxml',
        'bptypetostr',
        'bucketnumber',
        'buff',
        'buildquery',
        'businessdaysbetween',
        'by',
        'bytes',
        'cachedappprefix',
        'cachedroot',
        'callboolean',
        'callbooleanmethod',
        'callbytemethod',
        'callcharmethod',
        'calldoublemethod',
        'calledname',
        'callfirst',
        'callfloat',
        'callfloatmethod',
        'callint',
        'callintmethod',
        'calllongmethod',
        'callnonvirtualbooleanmethod',
        'callnonvirtualbytemethod',
        'callnonvirtualcharmethod',
        'callnonvirtualdoublemethod',
        'callnonvirtualfloatmethod',
        'callnonvirtualintmethod',
        'callnonvirtuallongmethod',
        'callnonvirtualobjectmethod',
        'callnonvirtualshortmethod',
        'callnonvirtualvoidmethod',
        'callobject',
        'callobjectmethod',
        'callshortmethod',
        'callsite_col',
        'callsite_file',
        'callsite_line',
        'callstack',
        'callstaticboolean',
        'callstaticbooleanmethod',
        'callstaticbytemethod',
        'callstaticcharmethod',
        'callstaticdoublemethod',
        'callstaticfloatmethod',
        'callstaticint',
        'callstaticintmethod',
        'callstaticlongmethod',
        'callstaticobject',
        'callstaticobjectmethod',
        'callstaticshortmethod',
        'callstaticstring',
        'callstaticvoidmethod',
        'callstring',
        'callvoid',
        'callvoidmethod',
        'cancel',
        'cap',
        'capa',
        'capabilities',
        'capi',
        'cbrt',
        'cc',
        'ceil',
        'chardigitvalue',
        'charname',
        'charset',
        'chartype',
        'checkdebugging',
        'checked',
        'checkuser',
        'childnodes',
        'chk',
        'chmod',
        'choosecolumntype',
        'chown',
        'chunked',
        'circle',
        'class',
        'classid',
        'clear',
        'clonenode',
        'close',
        'closepath',
        'closeprepared',
        'closewrite',
        'code',
        'codebase',
        'codetype',
        'colmap',
        'colorspace',
        'column_blob',
        'column_count',
        'column_decltype',
        'column_double',
        'column_int64',
        'column_name',
        'column_text',
        'column_type',
        'command',
        'comments',
        'compare',
        'comparecodepointorder',
        'componentdelimiter',
        'components',
        'composite',
        'compress',
        'concat',
        'condtoint',
        'configureds',
        'configuredskeys',
        'connect',
        'connection',
        'connectionhandler',
        'connhandler',
        'consume_domain',
        'consume_label',
        'consume_message',
        'consume_rdata',
        'consume_string',
        'contains',
        'content_disposition',
        'content_transfer_encoding',
        'content_type',
        'content',
        'contentlength',
        'contents',
        'contenttype',
        'continuation',
        'continuationpacket',
        'continuationpoint',
        'continuationstack',
        'continue',
        'contrast',
        'conventionaltop',
        'convert',
        'cookie',
        'cookies',
        'cookiesarray',
        'cookiesary',
        'copyto',
        'cos',
        'cosh',
        'count',
        'countkeys',
        'country',
        'countusersbygroup',
        'crc',
        'create',
        'createattribute',
        'createattributens',
        'createcdatasection',
        'createcomment',
        'createdocument',
        'createdocumentfragment',
        'createdocumenttype',
        'createelement',
        'createelementns',
        'createentityreference',
        'createindex',
        'createprocessinginstruction',
        'createtable',
        'createtextnode',
        'criteria',
        'crop',
        'csscontent',
        'curl',
        'current',
        'currentfile',
        'curveto',
        'd',
        'data',
        'databasecolumnnames',
        'databasecolumns',
        'databasemap',
        'databasename',
        'datasourcecolumnnames',
        'datasourcecolumns',
        'datasourcemap',
        'date',
        'day',
        'dayofmonth',
        'dayofweek',
        'dayofweekinmonth',
        'dayofyear',
        'days',
        'daysbetween',
        'db',
        'dbtablestable',
        'debug',
        'declare',
        'decodebase64',
        'decodehex',
        'decodehtml',
        'decodeqp',
        'decodeurl',
        'decodexml',
        'decompose',
        'decomposeassignment',
        'defaultcontentrepresentation',
        'defer',
        'deg2rad',
        'dele',
        'delete',
        'deletedata',
        'deleteglobalref',
        'deletelocalref',
        'delim',
        'depth',
        'dereferencepointer',
        'describe',
        'description',
        'deserialize',
        'detach',
        'detectcharset',
        'didinclude',
        'difference',
        'digit',
        'dir',
        'displaycountry',
        'displaylanguage',
        'displayname',
        'displayscript',
        'displayvariant',
        'div',
        'dns_response',
        'do',
        'doatbegins',
        'doatends',
        'doccomment',
        'doclose',
        'doctype',
        'document',
        'documentelement',
        'documentroot',
        'domainbody',
        'done',
        'dosessions',
        'dowithclose',
        'dowlocal',
        'download',
        'drawtext',
        'drop',
        'dropindex',
        'dsdbtable',
        'dshoststable',
        'dsinfo',
        'dst',
        'dstable',
        'dstoffset',
        'dtdid',
        'dup',
        'dup2',
        'each',
        'eachbyte',
        'eachcharacter',
        'eachchild',
        'eachcomponent',
        'eachdir',
        'eachdirpath',
        'eachdirpathrecursive',
        'eachentry',
        'eachfile',
        'eachfilename',
        'eachfilepath',
        'eachfilepathrecursive',
        'eachkey',
        'eachline',
        'eachlinebreak',
        'eachmatch',
        'eachnode',
        'eachpair',
        'eachpath',
        'eachpathrecursive',
        'eachrow',
        'eachsub',
        'eachword',
        'eachwordbreak',
        'element',
        'eligiblepath',
        'eligiblepaths',
        'encodebase64',
        'encodehex',
        'encodehtml',
        'encodehtmltoxml',
        'encodemd5',
        'encodepassword',
        'encodeqp',
        'encodesql',
        'encodesql92',
        'encodeurl',
        'encodevalue',
        'encodexml',
        'encoding',
        'enctype',
        'end',
        'endjs',
        'endssl',
        'endswith',
        'endtls',
        'enhance',
        'ensurestopped',
        'entities',
        'entry',
        'env',
        'equals',
        'era',
        'erf',
        'erfc',
        'err',
        'errcode',
        'errmsg',
        'error',
        'errors',
        'errstack',
        'escape_member',
        'establisherrorstate',
        'exceptioncheck',
        'exceptionclear',
        'exceptiondescribe',
        'exceptionoccurred',
        'exchange',
        'execinits',
        'execinstalls',
        'execute',
        'executelazy',
        'executenow',
        'exists',
        'exit',
        'exitcode',
        'exp',
        'expire',
        'expireminutes',
        'expiresminutes',
        'expm1',
        'export16bits',
        'export32bits',
        'export64bits',
        'export8bits',
        'exportas',
        'exportbytes',
        'exportfdf',
        'exportpointerbits',
        'exportsigned16bits',
        'exportsigned32bits',
        'exportsigned64bits',
        'exportsigned8bits',
        'exportstring',
        'expose',
        'extendedyear',
        'extensiondelimiter',
        'extensions',
        'extract',
        'extractfast',
        'extractfastone',
        'extractimage',
        'extractone',
        'f',
        'fabs',
        'fail',
        'failnoconnectionhandler',
        'family',
        'fatalerror',
        'fcgireq',
        'fchdir',
        'fchmod',
        'fchown',
        'fd',
        'features',
        'fetchdata',
        'fieldnames',
        'fieldposition',
        'fieldstable',
        'fieldtype',
        'fieldvalue',
        'file',
        'filename',
        'filenames',
        'filequeue',
        'fileuploads',
        'fileuploadsary',
        'filterinputcolumn',
        'finalize',
        'find',
        'findall',
        'findandmodify',
        'findbucket',
        'findcase',
        'findclass',
        'findcount',
        'finddescendant',
        'findfirst',
        'findinclude',
        'findinctx',
        'findindex',
        'findlast',
        'findpattern',
        'findposition',
        'findsymbols',
        'first',
        'firstchild',
        'firstcomponent',
        'firstdayofweek',
        'firstnode',
        'fixformat',
        'flags',
        'fliph',
        'flipv',
        'floor',
        'flush',
        'foldcase',
        'foo',
        'for',
        'forcedrowid',
        'foreach',
        'foreachaccept',
        'foreachbyte',
        'foreachcharacter',
        'foreachchild',
        'foreachday',
        'foreachentry',
        'foreachfile',
        'foreachfilename',
        'foreachkey',
        'foreachline',
        'foreachlinebreak',
        'foreachmatch',
        'foreachnode',
        'foreachpair',
        'foreachpathcomponent',
        'foreachrow',
        'foreachspool',
        'foreachsub',
        'foreachwordbreak',
        'form',
        'format',
        'formatas',
        'formatcontextelement',
        'formatcontextelements',
        'formatnumber',
        'free',
        'frexp',
        'from',
        'fromname',
        'fromport',
        'fromreflectedfield',
        'fromreflectedmethod',
        'front',
        'fsync',
        'ftpdeletefile',
        'ftpgetlisting',
        'ftruncate',
        'fullpath',
        'fx',
        'gamma',
        'gatewayinterface',
        'gen',
        'generatechecksum',
        'get',
        'getabswidth',
        'getalignment',
        'getappsource',
        'getarraylength',
        'getattr',
        'getattribute',
        'getattributenamespace',
        'getattributenode',
        'getattributenodens',
        'getattributens',
        'getbarheight',
        'getbarmultiplier',
        'getbarwidth',
        'getbaseline',
        'getbold',
        'getbooleanarrayelements',
        'getbooleanarrayregion',
        'getbooleanfield',
        'getbordercolor',
        'getborderwidth',
        'getbytearrayelements',
        'getbytearrayregion',
        'getbytefield',
        'getchararrayelements',
        'getchararrayregion',
        'getcharfield',
        'getclass',
        'getcode',
        'getcolor',
        'getcolumn',
        'getcolumncount',
        'getcolumns',
        'getdatabasebyalias',
        'getdatabasebyid',
        'getdatabasebyname',
        'getdatabasehost',
        'getdatabasetable',
        'getdatabasetablebyalias',
        'getdatabasetablebyid',
        'getdatabasetablepart',
        'getdatasource',
        'getdatasourcedatabase',
        'getdatasourcedatabasebyid',
        'getdatasourcehost',
        'getdatasourceid',
        'getdatasourcename',
        'getdefaultstorage',
        'getdoublearrayelements',
        'getdoublearrayregion',
        'getdoublefield',
        'getelementbyid',
        'getelementsbytagname',
        'getelementsbytagnamens',
        'getencoding',
        'getface',
        'getfield',
        'getfieldid',
        'getfile',
        'getfloatarrayelements',
        'getfloatarrayregion',
        'getfloatfield',
        'getfont',
        'getformat',
        'getfullfontname',
        'getgroup',
        'getgroupid',
        'getheader',
        'getheaders',
        'gethostdatabase',
        'gethtmlattr',
        'gethtmlattrstring',
        'getinclude',
        'getintarrayelements',
        'getintarrayregion',
        'getintfield',
        'getisocomment',
        'getitalic',
        'getlasterror',
        'getlcapitype',
        'getlibrary',
        'getlongarrayelements',
        'getlongarrayregion',
        'getlongfield',
        'getmargins',
        'getmethodid',
        'getmode',
        'getnameditem',
        'getnameditemns',
        'getnode',
        'getnumericvalue',
        'getobjectarrayelement',
        'getobjectclass',
        'getobjectfield',
        'getpadding',
        'getpagenumber',
        'getparts',
        'getprefs',
        'getpropertyvalue',
        'getprowcount',
        'getpsfontname',
        'getrange',
        'getrowcount',
        'getset',
        'getshortarrayelements',
        'getshortarrayregion',
        'getshortfield',
        'getsize',
        'getsortfieldspart',
        'getspacing',
        'getstaticbooleanfield',
        'getstaticbytefield',
        'getstaticcharfield',
        'getstaticdoublefield',
        'getstaticfieldid',
        'getstaticfloatfield',
        'getstaticintfield',
        'getstaticlongfield',
        'getstaticmethodid',
        'getstaticobjectfield',
        'getstaticshortfield',
        'getstatus',
        'getstringchars',
        'getstringlength',
        'getstyle',
        'getsupportedencodings',
        'gettablebyid',
        'gettext',
        'gettextalignment',
        'gettextsize',
        'gettrigger',
        'gettype',
        'getunderline',
        'getuniquealiasname',
        'getuser',
        'getuserbykey',
        'getuserid',
        'getversion',
        'getzipfilebytes',
        'givenblock',
        'gmt',
        'gotconnection',
        'gotfileupload',
        'groupby',
        'groupcolumns',
        'groupcount',
        'groupjoin',
        'handlebreakpointget',
        'handlebreakpointlist',
        'handlebreakpointremove',
        'handlebreakpointset',
        'handlebreakpointupdate',
        'handlecontextget',
        'handlecontextnames',
        'handlecontinuation',
        'handledefinitionbody',
        'handledefinitionhead',
        'handledefinitionresource',
        'handledevconnection',
        'handleevalexpired',
        'handlefeatureget',
        'handlefeatureset',
        'handlelassoappcontent',
        'handlelassoappresponse',
        'handlenested',
        'handlenormalconnection',
        'handlepop',
        'handleresource',
        'handlesource',
        'handlestackget',
        'handlestderr',
        'handlestdin',
        'handlestdout',
        'handshake',
        'hasattribute',
        'hasattributens',
        'hasattributes',
        'hasbinaryproperty',
        'haschildnodes',
        'hasexpired',
        'hasfeature',
        'hasfield',
        'hash',
        'hashtmlattr',
        'hasmethod',
        'hastable',
        'hastrailingcomponent',
        'hasvalue',
        'head',
        'header',
        'headerbytes',
        'headers',
        'headersarray',
        'headersmap',
        'height',
        'histogram',
        'home',
        'host',
        'hostcolumnnames',
        'hostcolumnnames2',
        'hostcolumns',
        'hostcolumns2',
        'hostdatasource',
        'hostextra',
        'hostid',
        'hostisdynamic',
        'hostmap',
        'hostmap2',
        'hostname',
        'hostpassword',
        'hostport',
        'hostschema',
        'hosttableencoding',
        'hosttonet16',
        'hosttonet32',
        'hosttonet64',
        'hostusername',
        'hour',
        'hourofampm',
        'hourofday',
        'hoursbetween',
        'href',
        'hreflang',
        'htmlcontent',
        'htmlizestacktrace',
        'htmlizestacktracelink',
        'httpaccept',
        'httpacceptencoding',
        'httpacceptlanguage',
        'httpauthorization',
        'httpcachecontrol',
        'httpconnection',
        'httpcookie',
        'httpequiv',
        'httphost',
        'httpreferer',
        'httpreferrer',
        'httpuseragent',
        'hypot',
        'id',
        'idealinmemory',
        'idle',
        'idmap',
        'ifempty',
        'ifkey',
        'ifnotempty',
        'ifnotkey',
        'ignorecase',
        'ilogb',
        'imgptr',
        'implementation',
        'import16bits',
        'import32bits',
        'import64bits',
        'import8bits',
        'importas',
        'importbytes',
        'importfdf',
        'importnode',
        'importpointer',
        'importstring',
        'in',
        'include',
        'includebytes',
        'includelibrary',
        'includelibraryonce',
        'includeonce',
        'includes',
        'includestack',
        'indaylighttime',
        'index',
        'init',
        'initialize',
        'initrequest',
        'inits',
        'inneroncompare',
        'input',
        'inputcolumns',
        'inputtype',
        'insert',
        'insertback',
        'insertbefore',
        'insertdata',
        'insertfirst',
        'insertfrom',
        'insertfront',
        'insertinternal',
        'insertlast',
        'insertpage',
        'install',
        'installs',
        'integer',
        'internalsubset',
        'interrupt',
        'intersection',
        'inttocond',
        'invoke',
        'invokeautocollect',
        'invokeuntil',
        'invokewhile',
        'ioctl',
        'isa',
        'isalive',
        'isallof',
        'isalnum',
        'isalpha',
        'isanyof',
        'isbase',
        'isblank',
        'iscntrl',
        'isdigit',
        'isdir',
        'isdirectory',
        'isempty',
        'isemptyelement',
        'isfirststep',
        'isfullpath',
        'isgraph',
        'ishttps',
        'isidle',
        'isinstanceof',
        'islink',
        'islower',
        'ismultipart',
        'isnan',
        'isnota',
        'isnotempty',
        'isnothing',
        'iso3country',
        'iso3language',
        'isopen',
        'isprint',
        'ispunct',
        'issameobject',
        'isset',
        'issourcefile',
        'isspace',
        'isssl',
        'issupported',
        'istitle',
        'istruetype',
        'istype',
        'isualphabetic',
        'isulowercase',
        'isupper',
        'isuuppercase',
        'isuwhitespace',
        'isvalid',
        'iswhitespace',
        'isxdigit',
        'isxhr',
        'item',
        'j0',
        'j1',
        'javascript',
        'jbarcode',
        'jcolor',
        'jfont',
        'jimage',
        'jlist',
        'jn',
        'jobjectisa',
        'join',
        'jread',
        'jscontent',
        'jsonfornode',
        'jsonhtml',
        'jsonisleaf',
        'jsonlabel',
        'jtable',
        'jtext',
        'julianday',
        'kernel',
        'key',
        'keycolumns',
        'keys',
        'keywords',
        'kill',
        'label',
        'lang',
        'language',
        'last_insert_rowid',
        'last',
        'lastaccessdate',
        'lastaccesstime',
        'lastchild',
        'lastcomponent',
        'lasterror',
        'lastinsertid',
        'lastnode',
        'lastpoint',
        'lasttouched',
        'lazyvalue',
        'ldexp',
        'leaveopen',
        'left',
        'length',
        'lgamma',
        'line',
        'linediffers',
        'linkto',
        'linktype',
        'list',
        'listactivedatasources',
        'listalldatabases',
        'listalltables',
        'listdatabasetables',
        'listdatasourcedatabases',
        'listdatasourcehosts',
        'listdatasources',
        'listen',
        'listgroups',
        'listgroupsbyuser',
        'listhostdatabases',
        'listhosts',
        'listmethods',
        'listnode',
        'listusers',
        'listusersbygroup',
        'loadcerts',
        'loaddatasourcehostinfo',
        'loaddatasourceinfo',
        'loadlibrary',
        'localaddress',
        'localname',
        'locals',
        'lock',
        'log',
        'log10',
        'log1p',
        'logb',
        'lookupnamespace',
        'lop',
        'lowagiefont',
        'lowercase',
        'makecolor',
        'makecolumnlist',
        'makecolumnmap',
        'makecookieyumyum',
        'makefullpath',
        'makeinheritedcopy',
        'makenonrelative',
        'makeurl',
        'map',
        'marker',
        'matches',
        'matchesstart',
        'matchposition',
        'matchstring',
        'matchtriggers',
        'max',
        'maxinmemory',
        'maxlength',
        'maxrows',
        'maxworkers',
        'maybeslash',
        'maybevalue',
        'md5hex',
        'media',
        'members',
        'merge',
        'meta',
        'method',
        'methodname',
        'millisecond',
        'millisecondsinday',
        'mime_boundary',
        'mime_contenttype',
        'mime_hdrs',
        'mime',
        'mimes',
        'min',
        'minute',
        'minutesbetween',
        'moddatestr',
        'mode',
        'modf',
        'modificationdate',
        'modificationtime',
        'modulate',
        'monitorenter',
        'monitorexit',
        'month',
        'moveto',
        'movetoattribute',
        'movetoattributenamespace',
        'movetoelement',
        'movetofirstattribute',
        'movetonextattribute',
        'msg',
        'mtime',
        'multiple',
        'n',
        'name',
        'named',
        'namespaceuri',
        'needinitialization',
        'net',
        'nettohost16',
        'nettohost32',
        'nettohost64',
        'new',
        'newbooleanarray',
        'newbytearray',
        'newchararray',
        'newdoublearray',
        'newfloatarray',
        'newglobalref',
        'newintarray',
        'newlongarray',
        'newobject',
        'newobjectarray',
        'newshortarray',
        'newstring',
        'next',
        'nextafter',
        'nextnode',
        'nextprime',
        'nextprune',
        'nextprunedelta',
        'nextsibling',
        'nodeforpath',
        'nodelist',
        'nodename',
        'nodetype',
        'nodevalue',
        'noop',
        'normalize',
        'notationname',
        'notations',
        'novaluelists',
        'numsets',
        'object',
        'objects',
        'objecttype',
        'onclick',
        'oncompare',
        'oncomparestrict',
        'onconvert',
        'oncreate',
        'ondblclick',
        'onkeydown',
        'onkeypress',
        'onkeyup',
        'onmousedown',
        'onmousemove',
        'onmouseout',
        'onmouseover',
        'onmouseup',
        'onreset',
        'onsubmit',
        'ontop',
        'open',
        'openappend',
        'openread',
        'opentruncate',
        'openwith',
        'openwrite',
        'openwriteonly',
        'orderby',
        'orderbydescending',
        'out',
        'output',
        'outputencoding',
        'ownerdocument',
        'ownerelement',
        'padleading',
        'padtrailing',
        'padzero',
        'pagecount',
        'pagerotation',
        'pagesize',
        'param',
        'paramdescs',
        'params',
        'parent',
        'parentdir',
        'parentnode',
        'parse_body',
        'parse_boundary',
        'parse_charset',
        'parse_content_disposition',
        'parse_content_transfer_encoding',
        'parse_content_type',
        'parse_hdrs',
        'parse_mode',
        'parse_msg',
        'parse_parts',
        'parse_rawhdrs',
        'parse',
        'parseas',
        'parsedocument',
        'parsenumber',
        'parseoneheaderline',
        'pass',
        'path',
        'pathinfo',
        'pathtouri',
        'pathtranslated',
        'pause',
        'payload',
        'pdifference',
        'perform',
        'performonce',
        'perms',
        'pid',
        'pixel',
        'pm',
        'polldbg',
        'pollide',
        'pop_capa',
        'pop_cmd',
        'pop_debug',
        'pop_err',
        'pop_get',
        'pop_ids',
        'pop_index',
        'pop_log',
        'pop_mode',
        'pop_net',
        'pop_res',
        'pop_server',
        'pop_timeout',
        'pop_token',
        'pop',
        'popctx',
        'popinclude',
        'populate',
        'port',
        'position',
        'postdispatch',
        'postparam',
        'postparams',
        'postparamsary',
        'poststring',
        'pow',
        'predispatch',
        'prefix',
        'preflight',
        'prepare',
        'prepared',
        'pretty',
        'prev',
        'previoussibling',
        'printsimplemsg',
        'private_compare',
        'private_find',
        'private_findlast',
        'private_merge',
        'private_rebalanceforinsert',
        'private_rebalanceforremove',
        'private_replaceall',
        'private_replacefirst',
        'private_rotateleft',
        'private_rotateright',
        'private_setrange',
        'private_split',
        'probemimetype',
        'provides',
        'proxying',
        'prune',
        'publicid',
        'pullhttpheader',
        'pullmimepost',
        'pulloneheaderline',
        'pullpost',
        'pullrawpost',
        'pullrawpostchunks',
        'pullrequest',
        'pullrequestline',
        'push',
        'pushctx',
        'pushinclude',
        'qdarray',
        'qdcount',
        'queryparam',
        'queryparams',
        'queryparamsary',
        'querystring',
        'queue_maintenance',
        'queue_messages',
        'queue_status',
        'queue',
        'quit',
        'r',
        'raw',
        'rawcontent',
        'rawdiff',
        'rawheader',
        'rawheaders',
        'rawinvokable',
        'read',
        'readattributevalue',
        'readbytes',
        'readbytesfully',
        'readdestinations',
        'readerror',
        'readidobjects',
        'readline',
        'readmessage',
        'readnumber',
        'readobject',
        'readobjecttcp',
        'readpacket',
        'readsomebytes',
        'readstring',
        'ready',
        'realdoc',
        'realpath',
        'receivefd',
        'recipients',
        'recover',
        'rect',
        'rectype',
        'red',
        'redirectto',
        'referrals',
        'refid',
        'refobj',
        'refresh',
        'rel',
        'remainder',
        'remoteaddr',
        'remoteaddress',
        'remoteport',
        'remove',
        'removeall',
        'removeattribute',
        'removeattributenode',
        'removeattributens',
        'removeback',
        'removechild',
        'removedatabasetable',
        'removedatasource',
        'removedatasourcedatabase',
        'removedatasourcehost',
        'removefield',
        'removefirst',
        'removefront',
        'removegroup',
        'removelast',
        'removeleading',
        'removenameditem',
        'removenameditemns',
        'removenode',
        'removesubnode',
        'removetrailing',
        'removeuser',
        'removeuserfromallgroups',
        'removeuserfromgroup',
        'rename',
        'renderbytes',
        'renderdocumentbytes',
        'renderstring',
        'replace',
        'replaceall',
        'replacechild',
        'replacedata',
        'replacefirst',
        'replaceheader',
        'replacepattern',
        'representnode',
        'representnoderesult',
        'reqid',
        'requestid',
        'requestmethod',
        'requestparams',
        'requesturi',
        'requires',
        'reserve',
        'reset',
        'resize',
        'resolutionh',
        'resolutionv',
        'resolvelinks',
        'resourcedata',
        'resourceinvokable',
        'resourcename',
        'resources',
        'respond',
        'restart',
        'restname',
        'result',
        'results',
        'resume',
        'retr',
        'retrieve',
        'returncolumns',
        'returntype',
        'rev',
        'reverse',
        'rewind',
        'right',
        'rint',
        'roll',
        'root',
        'rootmap',
        'rotate',
        'route',
        'rowsfound',
        'rset',
        'rule',
        'rules',
        'run',
        'running',
        'runonce',
        's',
        'sa',
        'safeexport8bits',
        'sameas',
        'save',
        'savedata',
        'scalb',
        'scale',
        'scanfordatasource',
        'scantasks',
        'scanworkers',
        'schemaname',
        'scheme',
        'script',
        'scriptextensions',
        'scriptfilename',
        'scriptname',
        'scripttype',
        'scripturi',
        'scripturl',
        'scrubkeywords',
        'search',
        'searchinbucket',
        'searchurl',
        'second',
        'secondsbetween',
        'seek',
        'select',
        'selected',
        'selectmany',
        'self',
        'send',
        'sendchunk',
        'sendfd',
        'sendfile',
        'sendpacket',
        'sendresponse',
        'separator',
        'serializationelements',
        'serialize',
        'serveraddr',
        'serveradmin',
        'servername',
        'serverport',
        'serverprotocol',
        'serversignature',
        'serversoftware',
        'sessionsdump',
        'sessionsmap',
        'set',
        'setalignment',
        'setattr',
        'setattribute',
        'setattributenode',
        'setattributenodens',
        'setattributens',
        'setbarheight',
        'setbarmultiplier',
        'setbarwidth',
        'setbaseline',
        'setbold',
        'setbooleanarrayregion',
        'setbooleanfield',
        'setbordercolor',
        'setborderwidth',
        'setbytearrayregion',
        'setbytefield',
        'setchararrayregion',
        'setcharfield',
        'setcode',
        'setcolor',
        'setcolorspace',
        'setcookie',
        'setcwd',
        'setdefaultstorage',
        'setdestination',
        'setdoublearrayregion',
        'setdoublefield',
        'setencoding',
        'setface',
        'setfieldvalue',
        'setfindpattern',
        'setfloatarrayregion',
        'setfloatfield',
        'setfont',
        'setformat',
        'setgeneratechecksum',
        'setheaders',
        'sethtmlattr',
        'setignorecase',
        'setinput',
        'setintarrayregion',
        'setintfield',
        'setitalic',
        'setlinewidth',
        'setlongarrayregion',
        'setlongfield',
        'setmarker',
        'setmaxfilesize',
        'setmode',
        'setname',
        'setnameditem',
        'setnameditemns',
        'setobjectarrayelement',
        'setobjectfield',
        'setpadding',
        'setpagenumber',
        'setpagerange',
        'setposition',
        'setrange',
        'setreplacepattern',
        'setshortarrayregion',
        'setshortfield',
        'setshowchecksum',
        'setsize',
        'setspacing',
        'setstaticbooleanfield',
        'setstaticbytefield',
        'setstaticcharfield',
        'setstaticdoublefield',
        'setstaticfloatfield',
        'setstaticintfield',
        'setstaticlongfield',
        'setstaticobjectfield',
        'setstaticshortfield',
        'setstatus',
        'settextalignment',
        'settextsize',
        'settimezone',
        'settrait',
        'setunderline',
        'sharpen',
        'shouldabort',
        'shouldclose',
        'showchecksum',
        'showcode39startstop',
        'showeanguardbars',
        'shutdownrd',
        'shutdownrdwr',
        'shutdownwr',
        'sin',
        'sinh',
        'size',
        'skip',
        'skiprows',
        'sort',
        'sortcolumns',
        'source',
        'sourcecolumn',
        'sourcefile',
        'sourceline',
        'specified',
        'split',
        'splitconnection',
        'splitdebuggingthread',
        'splitextension',
        'splittext',
        'splitthread',
        'splittoprivatedev',
        'splituppath',
        'sql',
        'sqlite3',
        'sqrt',
        'src',
        'srcpath',
        'sslerrfail',
        'stack',
        'standby',
        'start',
        'startone',
        'startup',
        'stat',
        'statement',
        'statementonly',
        'stats',
        'status',
        'statuscode',
        'statusmsg',
        'stdin',
        'step',
        'stls',
        'stop',
        'stoprunning',
        'storedata',
        'stripfirstcomponent',
        'striplastcomponent',
        'style',
        'styletype',
        'sub',
        'subject',
        'subnode',
        'subnodes',
        'substringdata',
        'subtract',
        'subtraits',
        'sum',
        'supportscontentrepresentation',
        'swapbytes',
        'systemid',
        't',
        'tabindex',
        'table',
        'tablecolumnnames',
        'tablecolumns',
        'tablehascolumn',
        'tableizestacktrace',
        'tableizestacktracelink',
        'tablemap',
        'tablename',
        'tables',
        'tabs',
        'tabstr',
        'tag',
        'tagname',
        'take',
        'tan',
        'tanh',
        'target',
        'tasks',
        'tb',
        'tell',
        'testexitcode',
        'testlock',
        'textwidth',
        'thenby',
        'thenbydescending',
        'threadreaddesc',
        'throw',
        'thrownew',
        'time',
        'timezone',
        'title',
        'titlecase',
        'to',
        'token',
        'tolower',
        'top',
        'toreflectedfield',
        'toreflectedmethod',
        'total_changes',
        'totitle',
        'touch',
        'toupper',
        'toxmlstring',
        'trace',
        'trackingid',
        'trait',
        'transform',
        'trigger',
        'trim',
        'trunk',
        'tryfinderrorfile',
        'trylock',
        'tryreadobject',
        'type',
        'typename',
        'uidl',
        'uncompress',
        'unescape',
        'union',
        'uniqueid',
        'unlock',
        'unspool',
        'up',
        'update',
        'updategroup',
        'upload',
        'uppercase',
        'url',
        'used',
        'usemap',
        'user',
        'usercolumns',
        'valid',
        'validate',
        'validatesessionstable',
        'value',
        'values',
        'valuetype',
        'variant',
        'version',
        'wait',
        'waitforcompletion',
        'warnings',
        'week',
        'weekofmonth',
        'weekofyear',
        'where',
        'width',
        'workers',
        'workinginputcolumns',
        'workingkeycolumns',
        'workingkeyfield_name',
        'workingreturncolumns',
        'workingsortcolumns',
        'write',
        'writebodybytes',
        'writebytes',
        'writeheader',
        'writeheaderbytes',
        'writeheaderline',
        'writeid',
        'writemessage',
        'writeobject',
        'writeobjecttcp',
        'writestring',
        'wroteheaders',
        'xhtml',
        'xmllang',
        'y0',
        'y1',
        'year',
        'yearwoy',
        'yn',
        'z',
        'zip',
        'zipfile',
        'zipfilename',
        'zipname',
        'zips',
        'zoneoffset',
    ),
    'Lasso 8 Member Tags': (
        'accept',
        'add',
        'addattachment',
        'addattribute',
        'addbarcode',
        'addchapter',
        'addcheckbox',
        'addchild',
        'addcombobox',
        'addcomment',
        'addcontent',
        'addhiddenfield',
        'addhtmlpart',
        'addimage',
        'addjavascript',
        'addlist',
        'addnamespace',
        'addnextsibling',
        'addpage',
        'addparagraph',
        'addparenttype',
        'addpart',
        'addpasswordfield',
        'addphrase',
        'addprevsibling',
        'addradiobutton',
        'addradiogroup',
        'addresetbutton',
        'addsection',
        'addselectlist',
        'addsibling',
        'addsubmitbutton',
        'addtable',
        'addtext',
        'addtextarea',
        'addtextfield',
        'addtextpart',
        'alarms',
        'annotate',
        'answer',
        'append',
        'appendreplacement',
        'appendtail',
        'arc',
        'asasync',
        'astype',
        'atbegin',
        'atbottom',
        'atend',
        'atfarleft',
        'atfarright',
        'attop',
        'attributecount',
        'attributes',
        'authenticate',
        'authorize',
        'backward',
        'baseuri',
        'bcc',
        'beanproperties',
        'beginswith',
        'bind',
        'bitand',
        'bitclear',
        'bitflip',
        'bitformat',
        'bitnot',
        'bitor',
        'bitset',
        'bitshiftleft',
        'bitshiftright',
        'bittest',
        'bitxor',
        'blur',
        'body',
        'boundary',
        'bytes',
        'call',
        'cancel',
        'capabilities',
        'cc',
        'chardigitvalue',
        'charname',
        'charset',
        'chartype',
        'children',
        'circle',
        'close',
        'closepath',
        'closewrite',
        'code',
        'colorspace',
        'command',
        'comments',
        'compare',
        'comparecodepointorder',
        'compile',
        'composite',
        'connect',
        'contains',
        'content_disposition',
        'content_transfer_encoding',
        'content_type',
        'contents',
        'contrast',
        'convert',
        'crop',
        'curveto',
        'data',
        'date',
        'day',
        'daylights',
        'dayofweek',
        'dayofyear',
        'decrement',
        'delete',
        'depth',
        'describe',
        'description',
        'deserialize',
        'detach',
        'detachreference',
        'difference',
        'digit',
        'document',
        'down',
        'drawtext',
        'dst',
        'dump',
        'endswith',
        'enhance',
        'equals',
        'errors',
        'eval',
        'events',
        'execute',
        'export16bits',
        'export32bits',
        'export64bits',
        'export8bits',
        'exportfdf',
        'exportstring',
        'extract',
        'extractone',
        'fieldnames',
        'fieldtype',
        'fieldvalue',
        'file',
        'find',
        'findindex',
        'findnamespace',
        'findnamespacebyhref',
        'findpattern',
        'findposition',
        'first',
        'firstchild',
        'fliph',
        'flipv',
        'flush',
        'foldcase',
        'foreach',
        'format',
        'forward',
        'freebusies',
        'freezetype',
        'freezevalue',
        'from',
        'fulltype',
        'generatechecksum',
        'get',
        'getabswidth',
        'getalignment',
        'getattribute',
        'getattributenamespace',
        'getbarheight',
        'getbarmultiplier',
        'getbarwidth',
        'getbaseline',
        'getbordercolor',
        'getborderwidth',
        'getcode',
        'getcolor',
        'getcolumncount',
        'getencoding',
        'getface',
        'getfont',
        'getformat',
        'getfullfontname',
        'getheaders',
        'getmargins',
        'getmethod',
        'getnumericvalue',
        'getpadding',
        'getpagenumber',
        'getparams',
        'getproperty',
        'getpsfontname',
        'getrange',
        'getrowcount',
        'getsize',
        'getspacing',
        'getsupportedencodings',
        'gettextalignment',
        'gettextsize',
        'gettype',
        'gmt',
        'groupcount',
        'hasattribute',
        'haschildren',
        'hasvalue',
        'header',
        'headers',
        'height',
        'histogram',
        'hosttonet16',
        'hosttonet32',
        'hour',
        'id',
        'ignorecase',
        'import16bits',
        'import32bits',
        'import64bits',
        'import8bits',
        'importfdf',
        'importstring',
        'increment',
        'input',
        'insert',
        'insertatcurrent',
        'insertfirst',
        'insertfrom',
        'insertlast',
        'insertpage',
        'integer',
        'intersection',
        'invoke',
        'isa',
        'isalnum',
        'isalpha',
        'isbase',
        'iscntrl',
        'isdigit',
        'isemptyelement',
        'islower',
        'isopen',
        'isprint',
        'isspace',
        'istitle',
        'istruetype',
        'isualphabetic',
        'isulowercase',
        'isupper',
        'isuuppercase',
        'isuwhitespace',
        'iswhitespace',
        'iterator',
        'javascript',
        'join',
        'journals',
        'key',
        'keys',
        'last',
        'lastchild',
        'lasterror',
        'left',
        'length',
        'line',
        'listen',
        'localaddress',
        'localname',
        'lock',
        'lookupnamespace',
        'lowercase',
        'marker',
        'matches',
        'matchesstart',
        'matchposition',
        'matchstring',
        'merge',
        'millisecond',
        'minute',
        'mode',
        'modulate',
        'month',
        'moveto',
        'movetoattributenamespace',
        'movetoelement',
        'movetofirstattribute',
        'movetonextattribute',
        'name',
        'namespaces',
        'namespaceuri',
        'nettohost16',
        'nettohost32',
        'newchild',
        'next',
        'nextsibling',
        'nodetype',
        'open',
        'output',
        'padleading',
        'padtrailing',
        'pagecount',
        'pagesize',
        'paraminfo',
        'params',
        'parent',
        'path',
        'pixel',
        'position',
        'prefix',
        'previoussibling',
        'properties',
        'rawheaders',
        'read',
        'readattributevalue',
        'readerror',
        'readfrom',
        'readline',
        'readlock',
        'readstring',
        'readunlock',
        'recipients',
        'rect',
        'refcount',
        'referrals',
        'remoteaddress',
        'remove',
        'removeall',
        'removeattribute',
        'removechild',
        'removecurrent',
        'removefirst',
        'removelast',
        'removeleading',
        'removenamespace',
        'removetrailing',
        'render',
        'replace',
        'replaceall',
        'replacefirst',
        'replacepattern',
        'replacewith',
        'reserve',
        'reset',
        'resolutionh',
        'resolutionv',
        'response',
        'results',
        'retrieve',
        'returntype',
        'reverse',
        'reverseiterator',
        'right',
        'rotate',
        'run',
        'save',
        'scale',
        'search',
        'second',
        'send',
        'serialize',
        'set',
        'setalignment',
        'setbarheight',
        'setbarmultiplier',
        'setbarwidth',
        'setbaseline',
        'setblocking',
        'setbordercolor',
        'setborderwidth',
        'setbytes',
        'setcode',
        'setcolor',
        'setcolorspace',
        'setdatatype',
        'setencoding',
        'setface',
        'setfieldvalue',
        'setfont',
        'setformat',
        'setgeneratechecksum',
        'setheight',
        'setlassodata',
        'setlinewidth',
        'setmarker',
        'setmode',
        'setname',
        'setpadding',
        'setpagenumber',
        'setpagerange',
        'setposition',
        'setproperty',
        'setrange',
        'setshowchecksum',
        'setsize',
        'setspacing',
        'settemplate',
        'settemplatestr',
        'settextalignment',
        'settextdata',
        'settextsize',
        'settype',
        'setunderline',
        'setwidth',
        'setxmldata',
        'sharpen',
        'showchecksum',
        'showcode39startstop',
        'showeanguardbars',
        'signal',
        'signalall',
        'size',
        'smooth',
        'sort',
        'sortwith',
        'split',
        'standards',
        'steal',
        'subject',
        'substring',
        'subtract',
        'swapbytes',
        'textwidth',
        'time',
        'timezones',
        'titlecase',
        'to',
        'todos',
        'tolower',
        'totitle',
        'toupper',
        'transform',
        'trim',
        'type',
        'unescape',
        'union',
        'uniqueid',
        'unlock',
        'unserialize',
        'up',
        'uppercase',
        'value',
        'values',
        'valuetype',
        'wait',
        'waskeyword',
        'week',
        'width',
        'write',
        'writelock',
        'writeto',
        'writeunlock',
        'xmllang',
        'xmlschematype',
        'year',
    )
}



"""
    pygments.lexers.tlb
    ~~~~~~~~~~~~~~~~~~~

    Lexers for TL-b.

    :copyright: Copyright 2006-present by the Pygments team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

from pygments.lexer import RegexLexer, include, words
from pygments.token import Operator, Name, \
    Number, Whitespace, Punctuation, Comment

__all__ = ['TlbLexer']


class TlbLexer(RegexLexer):
    """
    For TL-b source code.
    """

    name = 'Tl-b'
    aliases = ['tlb']
    filenames = ['*.tlb']
    url = 'https://docs.ton.org/#/overviews/TL-B'
    version_added = ''

    tokens = {
        'root': [
            (r'\s+', Whitespace),

            include('comments'),

            (r'[0-9]+', Number),
            (words((
                '+', '-', '*', '=', '?', '~', '.',
                '^', '==', '<', '>', '<=', '>=', '!='
            )), Operator),
            (words(('##', '#<', '#<=')), Name.Tag),
            (r'#[0-9a-f]*_?', Name.Tag),
            (r'\$[01]*_?', Name.Tag),

            (r'[a-zA-Z_][0-9a-zA-Z_]*', Name),

            (r'[;():\[\]{}]', Punctuation)
        ],

        'comments': [
            (r'//.*', Comment.Singleline),
            (r'/\*', Comment.Multiline, 'comment'),
        ],
        'comment': [
            (r'[^/*]+', Comment.Multiline),
            (r'/\*', Comment.Multiline, '#push'),
            (r'\*/', Comment.Multiline, '#pop'),
            (r'[*/]', Comment.Multiline),
        ],
    }



"""
    pygments.styles.murphy
    ~~~~~~~~~~~~~~~~~~~~~~

    Murphy's style from CodeRay.

    :copyright: Copyright 2006-present by the Pygments team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

from pygments.style import Style
from pygments.token import Keyword, Name, Comment, String, Error, \
     Number, Operator, Generic, Whitespace


__all__ = ['MurphyStyle']


class MurphyStyle(Style):
    """
    Murphy's style from CodeRay.
    """
    name = 'murphy'
    
    styles = {
        Whitespace:                "#bbbbbb",
        Comment:                   "#666 italic",
        Comment.Preproc:           "#579 noitalic",
        Comment.Special:           "#c00 bold",

        Keyword:                   "bold #289",
        Keyword.Pseudo:            "#08f",
        Keyword.Type:              "#66f",

        Operator:                  "#333",
        Operator.Word:             "bold #000",

        Name.Builtin:              "#072",
        Name.Function:             "bold #5ed",
        Name.Class:                "bold #e9e",
        Name.Namespace:            "bold #0e84b5",
        Name.Exception:            "bold #F00",
        Name.Variable:             "#036",
        Name.Variable.Instance:    "#aaf",
        Name.Variable.Class:       "#ccf",
        Name.Variable.Global:      "#f84",
        Name.Constant:             "bold #5ed",
        Name.Label:                "bold #970",
        Name.Entity:               "#800",
        Name.Attribute:            "#007",
        Name.Tag:                  "#070",
        Name.Decorator:            "bold #555",

        String:                    "bg:#e0e0ff",
        String.Char:               "#88F bg:",
        String.Doc:                "#D42 bg:",
        String.Interpol:           "bg:#eee",
        String.Escape:             "bold #666",
        String.Regex:              "bg:#e0e0ff #000",
        String.Symbol:             "#fc8 bg:",
        String.Other:              "#f88",

        Number:                    "bold #60E",
        Number.Integer:            "bold #66f",
        Number.Float:              "bold #60E",
        Number.Hex:                "bold #058",
        Number.Oct:                "bold #40E",

        Generic.Heading:           "bold #000080",
        Generic.Subheading:        "bold #800080",
        Generic.Deleted:           "#A00000",
        Generic.Inserted:          "#00A000",
        Generic.Error:             "#FF0000",
        Generic.Emph:              "italic",
        Generic.Strong:            "bold",
        Generic.EmphStrong:        "bold italic",
        Generic.Prompt:            "bold #c65d09",
        Generic.Output:            "#888",
        Generic.Traceback:         "#04D",

        Error:                     "#F00 bg:#FAA"
    }
